package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0D```````````(``P`!````P)8$"#0```"0Y````````#0`(``'
M`"@`&@`9``8````T````-(`$"#2`!`C@````X`````4````$`````P```!0!
M```4@00(%($$"!4````5````!`````$````!``````````"`!`@`@`0(S-\`
M`,S?```%`````!````$`````X````&`%"`!@!0A4`@``]`8```8`````$```
M`@```$S@``!,8`4(3&`%"/@```#X````!@````0````$````+`$``"R!!`@L
M@00(&````!@````$````!````%#E=&2XWP``N%\%"+A?!0@4````%`````0`
M```$````+VQI8F5X96,O;&0M96QF+G-O+C$`````"`````0````!````1G)E
M94)31`"X0`P`80```&8````````````````````)`````````%P```!;````
M5P``````````````9`````````!$````6@`````````W````/P```#H````.
M````-@```$@```!/````10```````````````````"$```!8````+@````$`
M````````,0```%$````L````8``````````&````&@```&$````;````````
M`"H`````````7P```!`````M````7@````````!*````*`````4```!-````
M8P```#T```!!````)0```%0````8````90`````````P````(`````````!'
M`````````````````````````%````!#````-````%8```!=````'@``````
M`````````````%4````R````0````%,```!9````#0`````````/````!```
M`````````````````#@`````````'P```!0`````````*P```&(`````````
M````````````````````````````````````````````````````````````
M``````````P`````````````````````````````````````````````````
M```````````````````2`````P```!D````(```````````````+````````
M````````````````````````````````````````````*0`````````=````
M``````H````B`````````"0``````````````````````````@``````````
M```````````````U```````````````\`````````````````````````#D`
M`````````````",````<````!P```"<`````````$0```"8`````````````
M`#X`````````.P```$P````O```````````````S````%P```$L```!"````
M`````!,`````````%@```%(```!.``````````````!)````%0````````!&
M``````````````````````````P`````````*@```!(```#7`@```````#0`
M```2````%P````````!W"@``$@```"D```!@8@4(`0```!$`%P!A`P``````
M`#8````2````LP,``,#H!`B2`0``$@`,`$````!,8`4(`````!$`\?_J`@``
M```````````2````]P(```````"8````$@```!T#````````6@```!(```!)
M`````````/<````2````5P````````#G````$@```&,`````````.@$``!(`
M``#``P``8/P$"`D````2``P`=````&1B!0@$````$0`7`-$#```,8`4(!```
M`!$`$`!X`@``:&(%""`````1`!<`?@````````"B!P``$@```(T```"(8@4(
M!````!$`%P#;`P``,.,$"$H````2``P`EP````````!6`P``$@```.D#``"`
MZ@0(]0```!(`#``K`P````````4````2````#@,```````#9"P``$@```*4`
M``",8@4(`0```!$`%P`:!```V)($"``````2``H`L@`````````E!0``$@``
M`+T`````````C0```!(```#*`````````$0!```2````V````/!F!0@$````
M$0`7`.``````````"P,``!(```#_`@```````$T````2````!P,`````````
M````$@```/4#``#`[00(W`$``!(`#`#K`````````$@````2`````@0``'#\
M!`@#`P``$@`,`!@$``"`_P0()````!(`#``6`P```````#0````2````WP(`
M``!@!0@$````$0`0`(,#``#`E@0(&0```!(`#`!3`P`````````````2````
MZP(`````````````$@```#4#````````*P```!(````D`P```````$`````2
M````(`0``*#O!`@,#```$@`,`/H`````````"00``!(```"R`@``````````
M```2````3@(````````X````$@```,`"````````=P```!(````M!```@.L$
M"&0````2``P`\`(```````"#````$@````,!``"-8@4(`0```!$`%P`]`P``
M`````',````2````$0$``/R4!`C1`0``$@```"$!``"08@4(!````!$`%P!^
M`P``5&(%"``````0`/'_8`(```````!-````$@```#D$``#PZP0(T`$``!(`
M#``^!```L.<$"`,!```2``P`4`0``+#[!`BO````$@`,`#$!``"48@4(`0``
M`!$`%P`\`0``'``%"``````2``T`0@$````````'&0``$@```*$$````````
M'0```!(```!;`@```````&L````2````<`(```````!)````$@```%`!````
M````1@```!(```!.`P```````$,````2````<0,`````````````$@````P"
M````````9P8``!(```!@`0```````#X````2````=P,``%1B!0@`````$`#Q
M_Y$"````````20```!(```!K`0``6&$%"``````1`/'_B@,``/1F!0@`````
M$`#Q_[@"````````=````!(```"!`0``E6(%"`$````1`!<`C`$``)AB!0@3
M````$0`7`)@"``"L8@4(!````!$`%P`8`@```````)L(```2````JP(`````
M````````$@```&8$``"`XP0(*````!(`#`";`0```````(4````2````Q@(`
M```````:````$@```(($``#@EP0(0````!(`#`"R`0``L&(%"`0````1`!<`
M3`,````````K````$@```(\$``!@Z@0('P```!(`#`"X`0``M&(%"`0````1
M`!<`B@(`````````````$@```,,!````````GP(``!(```#1`0``N&(%"`0`
M```1`!<`6@,```````"+````$@```&@#````````HP```!(```!6`@``````
M`%L````2````W@$`````````````(````$0#````````-````!(```#R`0``
M`````"D````2````H@(`````````````$@`````"````````00```!(````3
M`@```````"\````2`````&QI8G!E<FPN<V\`4&5R;%]C<F]A:P!097)L7W-V
M7S)P=E]F;&%G<P!03%]P97)L7V1E<W1R=6-T7VQE=F5L`%]$64Y!34E#`%!E
M<FQ?879?<VAI9G0`4&5R;%]M9U]S970`4&5R;%]N97=84U]F;&%G<P!03%]C
M;VUP8W8`<&5R;%]C;VYS=')U8W0`4$Q?<&%R<V5R`%!E<FQ?9&]U;G=I;F0`
M4$Q?9&]?=6YD=6UP`'!E<FQ?<&%R<V4`4&5R;%]N97=35G!V`%!E<FQ?<W9?
M<V5T<'8`96YV:7)O;@!097)L7VYE=UA3`%!E<FQ?<WES7VEN:70S`'!E<FQ?
M<G5N`%!,7V5X:71?9FQA9W,`8F]O=%]$>6YA3&]A9&5R`%!,7V-U<G-T86-K
M:6YF;P!03%]T86EN=&5D`%]F:6YI`'!E<FQ?9&5S=')U8W0`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?86QL;V,`7T=,3T)!3%]/1D93151?5$%"3$5?`%!,7VEN
M7V5V86P`4$Q?;65M;W)Y7W=R87``4&5R;%]S879E7V1E<W1R=6-T;W)?>`!0
M3%]O<`!03%]T;W!?96YV`%!E<FQ?879?9F5T8V@`4$Q?979A;%]R;V]T`%]*
M=E]296=I<W1E<D-L87-S97,`4&5R;%]S>7-?=&5R;0!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]F<F5E`&QI8FTN<V\N-0!L:6)C<GEP="YS;RXU`&QI8G5T
M:6PN<V\N.`!L:6)T:'(N<V\N,P!?7V5R<F]R`')E860`;W!E;@!C;&]S90!L
M:6)C+G-O+C<`;65M;6]V90!?7W-T86-K7V-H:U]G=6%R9`!G971P:60`;65M
M8W!Y`%]?<W1D97)R<`!R96%D;&EN:P!G971U:60`<FUD:7(`<F5A9&1I<@!L
M<V5E:P!?7W-T86-K7V-H:U]F86EL`&9P<FEN=&8`7U]P<F]G;F%M90!L<W1A
M=`!S=')S='(`<W1R;F-M<`!S=')N8W!Y`'5N;&EN:P!R96%L;&]C`'-T<G1O
M:P!S=')D=7``;65M<V5T`%]I;FET7W1L<P!O<&5N9&ER`'-T<F-M<`!S<')I
M;G1F`&%T97AI=`!A8V-E<W,`<W1R;&5N`&5X96-V<`!C;&]S961I<@!M:V1I
M<@!?961A=&$`7U]B<W-?<W1A<G0`7V5N9``O=7-R+VQO8V%L+VQI8B]P97)L
M-2\U+C$T+VUA8V@O0T]210!P87)?:6YI=%]E;G8`<&%R7V-U<G)E;G1?97AE
M8P!M>5]P87)?<&P`<&%R7V5N=E]C;&5A;@!P87)?9&ER;F%M90!P87)?9FEN
M9'!R;V<`6%-?26YT97)N86QS7U!!4E]"3T]4`'AS7VEN:70`<&%R7VUK=&UP
M9&ER`'!A<E]C;&5A;G5P`&UA:6X`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!P
M87)?8F%S96YA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`1D)31%\Q
M+C`````````"```````"``$``0`"``(``@`````````!`````0`"```````!
M`````0`"``(````!``````````$````"``(``0````$``0`"``$``0`"``(`
M`@`"``$````"``,``@`!``(````"```````!``,``0`!``$````!`````@`#
M``(````"``(``@````$``@`!``$``@```````@`"``(``0````(``0````(`
M`0````(```````(``@`#`````@````(```````$``0!"`@``$````"````"P
M*'H'```#`*H$`````````0`!`&8"```0`````````+`H>@<```(`J@0`````
M``!@8@4(!00``&1B!0@%#P``:&(%"`41``"(8@4(!1,``(QB!0@%&0``C6(%
M"`4T``"08@4(!3<``)1B!0@%/0``E6(%"`5-``"88@4(!4X``*QB!0@%3P``
ML&(%"`56``"T8@4(!5D``+AB!0@%7```9&$%"`<!``!H804(!P(``&QA!0@'
M`P``<&$%"`<%``!T804(!P@``'AA!0@'"0``?&$%"`<*``"`804(!PL``(1A
M!0@'#```B&$%"`<-``",804(!Q(``)!A!0@'%0``E&$%"`<7``"8804(!Q@`
M`)QA!0@'&P``H&$%"`<<``"D804(!QT``*AA!0@''P``K&$%"`<@``"P804(
M!R$``+1A!0@'(P``N&$%"`<F``"\804(!RD``,!A!0@'*@``Q&$%"`<K``#(
M804(!RP``,QA!0@'+@``T&$%"`<O``#4804(!S```-AA!0@',0``W&$%"`<S
M``#@804(!S4``.1A!0@'-@``Z&$%"`<Y``#L804(!S\``/!A!0@'0```]&$%
M"`=!``#X804(!T(``/QA!0@'0P```&(%"`=$```$8@4(!T4```AB!0@'1@``
M#&(%"`='```08@4(!TD``!1B!0@'3```&&(%"`=0```<8@4(!U$``"!B!0@'
M4P``)&(%"`=4```H8@4(!U<``"QB!0@'6@``,&(%"`=;```T8@4(!UT``#AB
M!0@'7@``/&(%"`=?``!`8@4(!V$``$1B!0@'8@``2&(%"`=C``!,8@4(!V0`
M`%!B!0@'90``@^P,Z-`$``#H"VT``(/$#,,```#_-5QA!0C_)6!A!0@`````
M_R5D804(:`````#IX/____\E:&$%"&@(````Z=#_____)6QA!0AH$````.G`
M_____R5P804(:!@```#IL/____\E=&$%"&@@````Z:#_____)7AA!0AH*```
M`.F0_____R5\804(:#````#I@/____\E@&$%"&@X````Z7#_____)81A!0AH
M0````.E@_____R6(804(:$@```#I4/____\EC&$%"&A0````Z4#_____)9!A
M!0AH6````.DP_____R64804(:&````#I(/____\EF&$%"&AH````Z1#_____
M)9QA!0AH<````.D`_____R6@804(:'@```#I\/[___\EI&$%"&B`````Z>#^
M____):AA!0AHB````.G0_O___R6L804(:)````#IP/[___\EL&$%"&B8````
MZ;#^____);1A!0AHH````.F@_O___R6X804(:*@```#ID/[___\EO&$%"&BP
M````Z8#^____)<!A!0AHN````.EP_O___R7$804(:,````#I8/[___\ER&$%
M"&C(````Z5#^____)<QA!0AHT````.E`_O___R70804(:-@```#I,/[___\E
MU&$%"&C@````Z2#^____)=AA!0AHZ````.D0_O___R7<804(:/````#I`/[_
M__\EX&$%"&CX````Z?#]____)>1A!0AH``$``.G@_?___R7H804(:`@!``#I
MT/W___\E[&$%"&@0`0``Z<#]____)?!A!0AH&`$``.FP_?___R7T804(:"`!
M``#IH/W___\E^&$%"&@H`0``Z9#]____)?QA!0AH,`$``.F`_?___R4`8@4(
M:#@!``#I</W___\E!&(%"&A``0``Z6#]____)0AB!0AH2`$``.E0_?___R4,
M8@4(:%`!``#I0/W___\E$&(%"&A8`0``Z3#]____)11B!0AH8`$``.D@_?__
M_R488@4(:&@!``#I$/W___\E'&(%"&AP`0``Z0#]____)2!B!0AH>`$``.GP
M_/___R4D8@4(:(`!``#IX/S___\E*&(%"&B(`0``Z=#\____)2QB!0AHD`$`
M`.G`_/___R4P8@4(:)@!``#IL/S___\E-&(%"&B@`0``Z:#\____)3AB!0AH
MJ`$``.F0_/___R4\8@4(:+`!``#I@/S___\E0&(%"&BX`0``Z7#\____)41B
M!0AHP`$``.E@_/___R5(8@4(:,@!``#I4/S___\E3&(%"&C0`0``Z4#\____
M)5!B!0AHV`$``.DP_/__`````#'M58GE@^3PC44(@^P$4/]U!%+H"````,R0
MD)"0D)"058GE5U93@^P,BW4,BUT0A?:-?+,$B3WP9@4(?C6+`X7`="^C`&`%
M"`^V$(32=".#P`'K"@^V$(/``832=!2`^B]U\:,`8`4(#[80@\`!A-)U[+A,
M8`4(A<!T-(M%"(D$).C&_O__QP0D'``%".BZ_O__Z('[__^)?"0(B5PD!(DT
M).B)5```B00DZ/W]___H2/S__^O0D)"0D)"0D)"0D%6)Y8/L"(`]O&(%"`!T
M#.L<@\`$HPA@!0C_TJ$(8`4(BQ"%TG7KQ@6\8@4(`<G#D%6)Y8/L"*%4804(
MA<!T$K@`````A<!T"<<$)%1A!0C_T,G#D)"0D)"0D)"0D)"0D%6)Y5:+=0A3
M#[8.B?.$R70IH8`"!0B-5@$/M@#K#(GV#[8*@\(!A,ET$#C!=?(/M@J)TX/"
M`83)=?")V%M>7<-5B>575E.![+P+``")A93Y__^#P#B)A9SY___'A9CY__\`
M````BY6<^?__BP*+4@2#A9SY__\(B86@^?__B[6@^?__B<&)E:3Y__^+O:3Y
M__^)TP^DRP@QVP^DPA@QTL'A"`G3P>`8@>$``/\`#ZS^""4```#_B;6@^?__
M"<&+A:#Y___![P@)TP^L_A")M:#Y___![Q`E`/\```G!#[:%H/G__XF]I/G_
M_XN]F/G__XG."<:)V`G0B83]=/W__XFT_7#]__^+O:3Y__^+M:#Y__\/K/X(
MP>\(B?&)\(G[B?H/I,L(,=L/I,(8,=+!X0@)T\'@&('A``#_`"4```#_"<$/
MK/X("=/![PB)\"4`_P``#ZS^$`G!P>\0B?"+O9CY__\E_P```(G."<:)V`G0
MB;3]>/W__XF$_7S]__^#QP*#_Q")O9CY__\/A=7^__^-M=C]__^-?=B-M"8`
M````BPZ+7@2+1MB+5MS'1AP`````,<@QVC-&J#-6K#-&F#-6G(G!B=,/K-D?
M#Z3"`0'`"<&)3AB#Q@C!ZQ\Y_G7!BY64^?__B[V4^?__BP*+4@2)A2#U__^+
MC2#U__^)E23U__^+E93Y__^+=PB+?PR+G23U__^)M2CU__^)O2SU__^+O93Y
M__^+0A"+4A2)A:CY__^+A93Y__^)E:SY__^+=QB+?QR+E23U__^)M;#Y__^+
MM7#]__^)O;3Y__\#<""+A2#U__^!QIEY@EH/I,L%#ZS0&\'A!0G(BXVH^?__
MP>H;`<:+A2CU__\CC2CU___WT".%L/G__PG(`<:)M:C[___'A:S[__\`````
MB[TL]?__BX4H]?__B[4H]?__BY4L]?__BXT@]?__BYTD]?__#ZS^`@^DPAZ+
ME7S]___!X!X)QHN%>/W__\'O`C'_`86P^?__$96T^?__BX4@]?__BY4D]?__
M@86P^?__F7F"6H.5M/G__P`A\??0(?LCA:CY___WTB.5K/G__PG!BX6H^___
M"=.+E:S[__\!C;#Y__\1G;3Y__^+C:C[__^+G:S[__\/K-`;P>H;,=(/I,L%
MP>$%"<@!A;#Y__\1E;3Y__^+E;#Y__^+A2#U___'A6SZ__\`````QX6\^?__
M`````(F5:/K__XN5)/7__P^LT`+!Z@*)A8CY__^+A2#U__^)E8SY__^+E23U
M__^+C8CY__\/I,(>BY6$_?__P>`>"<&+A8#]__\!A:CY__^+A:C[__\1E:SY
M__^!A:CY__^9>8):@Y6L^?__`#'2,=OWT(F-N/G__XN-J/O___?2(XVX^?__
M(?`A^B';"=J+G6SZ__\)R(N-:/K__P&%J/G__Q&5K/G__XN%:/K__XN5;/K_
M_P^DRP7!X04/K-`;"<C!ZALQT@&%J/G__Q&5K/G__XN5J/G__XN%J/O__\>%
MO/S__P````#'A;3[__\`````B96X_/__BY6L^___#ZS0`L'J`HF%@/G__XN%
MJ/O__XF5A/G__XN5K/O__XN-@/G__P^DPAZ+E8S]___!X!X)P8N%B/W__XF-
ML/O__XN-:/K__P69>8):B85X^?__BX5H^O__@](``;5X^?__B95\^?__]]`1
MO7SY__\QTB.-L/O__S';(X6X^?__]](A^B';"=J+G;S\__\)R(N-N/S__P&%
M>/G__Q&5?/G__XN%N/S__XN5O/S__P^DRP7!X04/K-`;"<C!ZALQT@&%>/G_
M_Q&5?/G__XN5>/G__XN];/K__XN%:/K__XNU:/K__XF5,/S__XN5;/K__XN-
MN/S__\>%-/S__P`````/K/X"#Z3"'HN5E/W__\'@'@G&BX60_?__P>\",?\%
MF7F"6HF%</G__XN%N/G__X/2``&%</G__XN%N/S__XF5=/G__XN5O/G__Q&5
M=/G__S'2,=OWTO?0(?$CA;#[__\A^R'Z"=J+G33\__\)R(N-,/S__P&%</G_
M_Q&5=/G__XN%,/S__XN5-/S__P^DRP7!X04/K-`;"<C!ZALQT@&%</G__Q&5
M=/G__XN5</G__XN%N/S__\>%#/O__P````#'A<3\__\`````B94(^___BY6\
M_/__#ZS0`L'J`HF%:/G__XN%N/S__XF5;/G__XN5O/S__XN-:/G__P^DPAZ+
ME9S]___!X!X)P8N%F/W__XF-P/S__XN-,/S__P69>8):B85@^?__BX6P^___
M@](``85@^?__BX4P_/__B95D^?__BY6T^___$95D^?__,=(CC<#\__\QV_?0
M]](A\"'Z(=L)R`G:`85@^?__$95D^?__BY4,^___BXT(^___BX4(^___BYT,
M^___QX7$^?__`````,>%//S__P`````/K-`;#Z3+!<'A!0G(P>H;,=(!A6#Y
M__\1E63Y__^+E6#Y__^+A3#\__^)E<#Y__^+E33\__\/K-`"P>H"B858^?__
MBX4P_/__B95<^?__BY4T_/__BXU8^?__#Z3"'HN5I/W__\'@'@G!BX6@_?__
MB8TX_/__BXT(^___!9EY@EJ)A5#Y__^+A0C[__^#T@`!M5#Y__^)E53Y___W
MT!&]5/G__S'2(XTX_/__,=LCA<#\___WTB'Z(=L)V@G(`850^?__$954^?__
MBXW`^?__BY7$^?__BX7`^?__BYW$^?__B[T,^___B[4(^___#ZS0&P^DRP7!
MX04)R(N-P/G__\'J&S'2`850^?__$954^?__BY50^?__#ZS^`HN%"/O__\'O
M`C'_QX6\^___`````(F5N/O__XN5#/O__P^DPAZ+E:S]___!X!X)QHN%J/W_
M_P69>8):B85(^?__BX7`_/__@](``85(^?__BX7`^?__B95,^?__BY7$_/__
M$95,^?__,=(QV_?2]]`A\2.%./S__R'[(?H)V@G(`85(^?__$95,^?__BXVX
M^___BY6\^___BX6X^___BYV\^___QX5T^O__`````,>%S/G__P`````/K-`;
M#Z3+!<'A!0G(P>H;,=(!A4CY__\1E4SY__^+E4CY__^+A<#Y__^)E7#Z__^+
ME<3Y__\/K-`"P>H"B85`^?__BX7`^?__B95$^?__BY7$^?__BXU`^?__#Z3"
M'HN5M/W__\'@'@G!BX6P_?__B8W(^?__!9EY@EJ)A3CY__^#T@"+A3C\__\!
MA3CY__^)E3SY__^+E3S\__\1E3SY__\QTHN%N/O__S';]]*+C;C[__\A^B';
M(XW(^?__"=J+G73Z___WT"'P"<B+C7#Z__\!A3CY__\1E3SY__^+A7#Z__^+
ME73Z__\/I,L%P>$%QX7,_/__`````,>%Q/O__P`````/K-`;"<C!ZALQT@&%
M./G__Q&5//G__XN5./G__XN%N/O__XF5R/S__XN5O/O__P^LT`+!Z@*)A3#Y
M__^+A;C[__^)E33Y__^+E;S[__^+C3#Y__\/I,(>BY6\_?__P>`>"<&+A;C]
M__^)C<#[__\%F7F"6H/2`(F%*/G__XF5+/G__XN%</K__P&U*/G__XN-</K_
M_Q&]+/G__S'2(XW`^___]]`CA<CY__\QV_?2(=N+M7#Z__\A^HN]=/K__PG:
M"<B+G<S\__\!A2CY__\1E2SY__^+C<C\__^+E<S\__^+A<C\___'A43\__\`
M````#Z3+!<'A!0^LT!L)R,'J&S'2`84H^?__$94L^?__BY4H^?__#ZS^`HN%
M</K__\'O`C'_B95`_/__BY5T^O__#Z3"'HN5Q/W__\'@'@G&BX7`_?__!9EY
M@EJ#T@")A2#Y__^)E23Y__^+A<CY__\!A2#Y__^+A<C\__^+C<C\__^+E<SY
M__\1E23Y__\QTO?0,=LCA<#[___WTB'Q(?LA^@G:"<B+G43\__\!A2#Y__\1
ME23Y__^+C4#\__^+E43\__^+A4#\___'A13[__\`````#Z3+!<'A!0^LT!L)
MR,'J&S'2`84@^?__$94D^?__BY4@^?__BX7(_/__B940^___BY7,_/__#ZS0
M`L'J`HF%&/G__XN%R/S__XF5'/G__XN5S/S__XN-&/G__P^DPA[!X!X)P8F-
MT/S__XN%R/W__XN5S/W__XN-0/S__\>%U/S__P`````%F7F"6HF%$/G__XN%
MP/O__X/2``&%$/G__XN%0/S__XF5%/G__XN5Q/O__Q&5%/G__S'2(XW0_/__
M,=OWT/?2(?`A^B';"<B+C1#[__\)VHN=%/O__P&%$/G__Q&5%/G__XN%$/O_
M_XN5%/O__P^DRP7!X07'A=3Y__\`````#ZS0&PG(P>H;,=(!A1#Y__\1E13Y
M__^+E1#Y__^+A4#\__^)E=#Y__^+E43\__\/K-`"P>H"B84(^?__BX5`_/__
MB94,^?__BY5$_/__BXT(^?__QX5,_/__``````^DPAZ+E=3]___!X!X)P8N%
MT/W__XF-2/S__XN-$/O__P69>8):B84`^?__BX40^___@](``;4`^?__B94$
M^?__]]`1O03Y__\QTB.-2/S__S';(X70_/__]](A^B';"=J+G=3Y__\)R(N-
MT/G__P&%`/G__Q&5!/G__XN%T/G__XN5U/G__P^DRP7!X04/K-`;"<C!ZALQ
MT@&%`/G__Q&5!/G__XN5`/G__XF5R/O__XN]%/O__XN%$/O__XNU$/O__XN5
M%/O__XN-T/G__\>%S/O__P`````/K/X"#Z3"'HN5W/W__\'@'@G&BX78_?__
MP>\",?\%F7F"6HF%^/C__XN%T/S__X/2``&%^/C__XN%T/G__XF5_/C__XN5
MU/S__Q&5_/C__S'2,=OWTO?0(?$CA4C\__\A^R'Z"=J+G<S[__\)R(N-R/O_
M_P&%^/C__Q&5_/C__XN%R/O__XN5S/O__P^DRP7!X04/K-`;"<C!ZALQT@&%
M^/C__Q&5_/C__XN5^/C__XF5>/K__XN5U/G__XN%T/G__\>%?/K__P````#'
MA=SY__\`````#ZS0`L'J`HF%\/C__XN%T/G__XF5]/C__XN5U/G__XN-\/C_
M_P^DPAZ+E>3]___!X!X)P8N%X/W__XF-V/G__XN-R/O__P69>8):B87H^/__
MBX5(_/__@](``87H^/__BX7(^___B97L^/__BY5,_/__$97L^/__,=(CC=CY
M__\QV_?0]](A\"'Z(=L)R(N->/K__PG:BYU\^O__`87H^/__$97L^/__BX5X
M^O__BY5\^O__#Z3+!<'A!0^LT!L)R,'J&S'2`87H^/__$97L^/__BY7H^/__
MBX7(^___QX7<_/__`````,>%U/O__P````")E=C\__^+E<S[__\/K-`"P>H"
MB87@^/__BX7(^___B97D^/__BY7,^___BXW@^/__#Z3"'HN5[/W__\'@'@G!
MBX7H_?__B8W0^___BXUX^O__!9EY@EJ)A=CX__^+A7CZ__^#T@`!M=CX__^)
ME=SX___WT!&]W/C__S'2(XW0^___,=LCA=CY___WTB'Z(=L)VHN=W/S__PG(
MBXW8_/__`878^/__$97<^/__BX78_/__BY7<_/__#Z3+!<'A!0^LT!L)R,'J
M&S'2`878^/__$97<^/__BY78^/__B[U\^O__BX5X^O__B[5X^O__B950_/__
MBY5\^O__BXW8_/__QX54_/__``````^L_@(/I,(>BY7T_?__P>`>"<:+A?#]
M___![P(Q_P69>8):B870^/__BX78^?__@](``870^/__BX78_/__B974^/__
MBY7<^?__$974^/__,=(QV_?2]]`A\2.%T/O__R'[(?H)VHN=5/S__PG(BXU0
M_/__`870^/__$974^/__BX50_/__BY54_/__#Z3+!<'A!0^LT!L)R,'J&S'2
M`870^/__$974^/__BY70^/__BX78_/__QX4<^___`````,>%Y/S__P````")
ME1C[__^+E=S\__\/K-`"P>H"B87(^/__BX78_/__B97,^/__BY7<_/__BXW(
M^/__#Z3"'HN5_/W__\'@'@G!BX7X_?__B8W@_/__BXU0_/__!9EY@EJ)A<#X
M__^+A=#[__^#T@`!A<#X__^+A5#\__^)E<3X__^+E=3[__\1E<3X__\QTB.-
MX/S__S';]]#WTB'P(?HAVPG("=H!A<#X__\1E<3X__^+E1S[__^+C1C[__^+
MA1C[__^+G1S[___'A>3Y__\`````QX5<_/__``````^LT!L/I,L%P>$%"<C!
MZALQT@&%P/C__Q&5Q/C__XN5P/C__XN%4/S__XF5X/G__XN55/S__P^LT`+!
MZ@*)A;CX__^+A5#\__^)E;SX__^+E53\__^+C;CX__\/I,(>BY4$_O__P>`>
M"<&+A0#^__^)C5C\__^+C1C[__\%F7F"6HF%L/C__XN%&/O__X/2``&UL/C_
M_XF5M/C___?0$;VT^/__,=(CC5C\__\QVR.%X/S___?2(?HAVPG:"<@!A;#X
M__\1E;3X__^+C>#Y__^+E>3Y__^+A>#Y__^+G>3Y___'A=S[__\`````QX4D
M^___``````^LT!L/I,L%BYT<^___P>$%"<B+C1C[___!ZALQT@&%L/C__Q&5
MM/C__XN5L/C__P^LV0*+A1C[__^)SHN-X/G__\'K`HN=W/O__XF5V/O__XN5
M'/O__P^DPAZ+E=S[___!X!X)QHN%X/G__XFU(/O__XNU"/[___?0@<:9>8):
M`[7@_/__(XT@^___(X58_/__"<B+C=C[__\!QHN%V/O__P^DRP4/K-`;P>$%
M"<C!ZAL!QHFU@/K__XN=Y/G__XN%X/G__XN-X/G__XN5Y/G__XNU$/[__\>%
MA/K__P````"+O=S[__\/K-D"#Z3"'HN5A/K__\'@'@G!BX4@^___P>L",=N!
MQJ'KV6X#M5C\__\QR#.%V/O__\>%[/S__P`````!QHN%@/K__P^LT!O!ZAN)
MA1CU__^+A8#Z__^)E1SU__^+E83Z__\/I,(%P>`%B86H^/__BX48]?__"X6H
M^/__B96L^/__BY7<^___`<:+A=C[__^)M>C\__^+M=C[__\/I,(>BY4<_O__
M#ZS^`L'@'@G&BX48_O__P>\",?\%H>O9;HF%H/C__X/2`(N%(/O__P&%H/C_
M_XGPB96D^/__BY4D^___$96D^/__B?HQVC'(,=HSA8#Z__\!A:#X__\1E:3X
M__^+A>C\__^+E>S\___'A63\__\`````#ZS0&\'J&XF%$/7__XN%Z/S__XF5
M%/7__XN5[/S__P^DP@7!X`6)A9CX__^+A1#U__\+A9CX__^)E9SX__\QT@&%
MH/C__Q&5I/C__XN5H/C__XN%@/K__XF58/S__XN5A/K__P^LT`+!Z@*)A9#X
M__^+A8#Z__^)E93X__^+E83Z__\/I,(>B94,]?__BY60^/__P>`>B84(]?__
M"<*)E8CX__^+A93X__\+A0SU__^)E8CZ__^+E23^___'A8SZ__\`````B86,
M^/__BX4@_O__QX4L^___``````6AZ]ENB86`^/__BX6(^O__@](``8V`^/__
MBXU@_/__B96$^/__$9V$^/__,=(Q^C'P,=J+G63\__\SA>C\__\!A8#X__\1
ME83X__^+A6#\__\/I,L%BY5D_/__P>$%BYWL_/__#ZS0&PG(BXWH_/__P>H;
M,=(!A8#X__\1E83X__^+E8#X__\/K-D"BX7H_/__P>L",=N)E2C[__^+E>S\
M__\/I,(>BY4L_O__P>`>"<&+A2C^__\%H>O9;HF%>/C__XN%B/K__X/2``&U
M>/C__XNU*/O__XF5?/C__Q&]?/C__S'2,=HQR(N]+/O__S.%8/S__S':`85X
M^/__$95\^/__BX4H^___#Z3W!8N5+/O__\'F!8N]9/S__\>%[/G__P`````/
MK-`;"?"+M6#\___!ZALQT@&%>/C__Q&5?/C__XN5>/C__P^L_@*+A6#\___!
M[P(Q_XF5Z/G__XN59/S__P^DPAZ+E33^___!X!X)QHN%,/[__P6AZ]EN@](`
MB85P^/__BX6(^O__B95T^/__BY6,^O__`85P^/__B?`1E73X__^)^C':,<@Q
MVC.%*/O__P&%</C__Q&5=/C__XN%Z/G__XN5[/G__\>%Y/O__P`````/K-`;
MP>H;B84`]?__BX7H^?__B94$]?__BY7L^?__#Z3"!<'@!8F%:/C__XN%`/7_
M_PN%:/C__XF5;/C__S'2`85P^/__$95T^/__BY5P^/__BX4H^___B97@^___
MBY4L^___#ZS0`L'J`HF%8/C__XN%*/O__XF59/C__XN5+/O__P^DPA[!X!Z)
MA?CT__^)E?ST__^+E6#X___'A33[__\`````"<*+A63X__\+A?ST__^)E3#[
M__^)E5CX__^+E3S^__^)A5SX__^+A3C^__\%H>O9;HF%4/C__XN%,/O__X/2
M``&-4/C__XN-X/O__XF55/C__Q&=5/C__S'2,?HQ\#':BYWD^___,X7H^?__
M`850^/__$954^/__BX7@^___#Z3+!8N5Y/O__\'A!0^LT!L)R,'J&S'2`850
M^/__$954^/__BY50^/__B960^O__BYWL^?__BX7H^?__BXWH^?__BY7L^?__
MQX64^O__`````,>%]/S__P`````/K-D"#Z3"'HN51/[__\'@'@G!BX5`_O__
MP>L",=L%H>O9;HF%2/C__XN%,/O__X/2``&U2/C__XNUD/K__XF53/C__Q&]
M3/C__S'2,=HQR(N]E/K__S.%X/O__S':`85(^/__$95,^/__BX60^O__#Z3W
M!8N5E/K__\'F!8N]Y/O__P^LT!L)\(NUX/O__\'J&S'2`85(^/__$95,^/__
MBY5(^/__#ZS^`HN%X/O__\'O`C'_B97P_/__BY7D^___#Z3"'HN53/[__\'@
M'@G&BX5(_O__!:'KV6Z)A4#X__^#T@"+A3#[__\!A4#X__^)\(F51/C__XN5
M-/O__Q&51/C__XGZ,=HQR#':,X60^O__`85`^/__$95$^/__BX7P_/__BY7T
M_/__QX5L_/__``````^LT!O!ZAN)A?#T__^+A?#\__^)E?3T__^+E?3\__\/
MI,(%P>`%B84X^/__BX7P]/__"X4X^/__B94\^/__,=(!A4#X__\1E43X__^+
ME4#X__^+A9#Z__^)E6C\__^+E93Z__\/K-`"P>H"B84P^/__BX60^O__B94T
M^/__BY64^O__QX6<^O__``````^DPAZ)E>ST__^+E3#X___!X!Z)A>CT__\)
MPHN%-/C__PN%[/3__XF5F/K__XF5*/C__XN55/[__XF%+/C__XN%4/[__P6A
MZ]ENB84@^/__BX68^O__@](``8T@^/__BXUH_/__B94D^/__$9TD^/__,=(Q
M^C'P,=J+G6S\__\SA?#\__\!A2#X__\1E23X__^+A6C\__\/I,L%BY5L_/__
MP>$%#ZS0&PG(P>H;,=(!A2#X__\1E23X__^+E2#X__^+G?3\__^+A?#\__^+
MC?#\__^)E3C[__^+E?3\___'A3S[__\`````#ZS9`@^DPAZ+E5S^___!X!X)
MP8N%6/[__\'K`C';!:'KV6Z)A1CX__^+A9CZ__^#T@`!M1CX__^+M3C[__^)
ME1SX__\1O1SX__\QTC':,<B+O3S[__\SA6C\__\QV@&%&/C__Q&5'/C__XN%
M./O__P^D]P6+E3S[___!Y@4/K-`;"?#!ZALQT@&%&/C__Q&5'/C__XN5&/C_
M_XF5\/G__XN];/S__XN%:/S__XNU:/S__XN5;/S__\>%]/G__P`````/K/X"
M#Z3"'HN59/[__\'@'@G&BX5@_O__P>\",?\%H>O9;HF%$/C__X/2`(N%F/K_
M_P&%$/C__XGPB944^/__BY6<^O__$944^/__B?HQVC'(,=HSA3C[__\!A1#X
M__\1E13X__^+A?#Y__^+E?3Y__\/K-`;P>H;B87@]/__BX7P^?__B97D]/__
MBY7T^?__#Z3"!<'@!8F%"/C__XN%X/3__PN%"/C__XF5#/C__S'2`840^/__
M$944^/__BY40^/__BX4X^___QX7L^___`````,>%1/O__P````")E>C[__^+
ME3S[__\/K-`"P>H"B84`^/__BX4X^___B94$^/__BY4\^___#Z3"'HF5W/3_
M_XN5`/C__\'@'HF%V/3__PG"BX4$^/__"X7<]/__B95`^___B97X]___BY5L
M_O__B87\]___BX5H_O__!:'KV6Z)A?#W__^+A4#[__^#T@`!C?#W__^)E?3W
M__\1G?3W__\QTC'Z,?`QVC.%\/G__P&%\/?__Q&5]/?__XN5[/O__XN-Z/O_
M_XN%Z/O__XN=[/O__\>%I/K__P`````/K-`;#Z3+!8N=]/G__\'A!0G(BXWP
M^?__P>H;,=(!A?#W__\1E?3W__^+E?#W__\/K-D"BX7P^?__P>L",=N)E:#Z
M__^+E?3Y__\/I,(>BY5T_O__P>`>"<&+A7#^__\%H>O9;HF%Z/?__XN%0/O_
M_X/2``&UZ/?__XNUH/K__XF5[/?__Q&][/?__S'2,=HQR(N]I/K__S.%Z/O_
M_S':`87H]___$97L]___BX6@^O__#Z3W!8N5I/K__\'F!0^LT!L)\,'J&S'2
M`87H]___$97L]___BY7H]___B[WL^___BX7H^___B[7H^___B97X_/__BY7L
M^___QX7\_/__``````^L_@(/I,(>BY5\_O__P>`>"<:+A7C^___![P(Q_P6A
MZ]ENB87@]___@](`BX5`^___`87@]___B?")E>3W__^+E43[__\1E>3W__^)
M^C':,<@QVC.%H/K__P&%X/?__Q&5Y/?__XN%^/S__XN5_/S__P^LT!O!ZAN)
MA=#T__^+A?C\__^)E=3T__^+E?S\__\/I,(%P>`%B878]___BX70]/__"X78
M]___B97<]___,=(!A>#W__\1E>3W__^+E>#W__^+A:#Z___'A73\__\`````
MQX6L^O__`````(F5</S__XN5I/K__P^LT`+!Z@*)A=#W__^+A:#Z__^)E=3W
M__^+E:3Z__\/I,(>B97,]/__BY70]___P>`>B87(]/__"<*+A=3W__\+A<ST
M__^)E<CW__^)E:CZ__^+E83^__^)A<SW__^+A8#^__\%H>O9;HF%P/?__X/2
M``&-P/?__XF5Q/?__Q&=Q/?__S'2BX6H^O__,?HQVHN-</S__XN==/S__\>%
M3/O__P`````Q\#.%^/S__P&%P/?__Q&5Q/?__XN%</S__P^DRP6+E73\___!
MX06+G?S\__\/K-`;"<B+C?C\___!ZALQT@&%P/?__Q&5Q/?__XN5P/?__P^L
MV0*+A?C\___!ZP(QVXF52/O__XN5_/S__P^DPAZ+E8S^___!X!X)P8N%B/[_
M_P6AZ]ENB86X]___BX6H^O__@](``;6X]___B96\]___$;V\]___,=(QVC'(
M,=HSA7#\__\!A;CW__\1E;SW__^+M4C[__^+E4S[__^+A4C[__^+O4S[___'
MA?SY__\`````#ZS0&P^D]P6+O73\___!Y@4)\(NU</S__\'J&S'2`86X]___
M$96\]___BY6X]___#ZS^`HN%</S__\'O`C'_B97X^?__BY5T_/__#Z3"'HN5
ME/[__\'@'@G&BX60_O__!:'KV6Z)A;#W__^#T@"+A:CZ__\!A;#W__^)\(F5
MM/?__XN5K/K__Q&5M/?__XGZ,=HQR#':,X5(^___`86P]___$96T]___BY7\
M^?__BX7X^?__QX7T^___``````^LT!O!ZAN)A<#T__^+A?CY__^)E<3T__^+
ME?SY__\/I,(%P>`%B86H]___BX7`]/__"X6H]___B96L]___,=(!A;#W__\1
ME;3W__^+E;#W__^+A4C[__^)E?#[__^+E4S[__\/K-`"P>H"B86@]___BX5(
M^___B96D]___BY5,^___#Z3"'HF5O/3__XN5H/?__\'@'HF%N/3__PG"BX6D
M]___"X6\]/__B968]___B950^___B86<]___QX54^___`````(N%F/[__XN5
MG/[__\>%M/K__P`````%H>O9;HF%D/?__XN%4/O__X/2``&-D/?__XN-\/O_
M_XF5E/?__Q&=E/?__S'2,?HQ\#':BYWT^___,X7X^?__`860]___$964]___
MBX7P^___#Z3+!8N5]/O__\'A!8N=_/G__P^LT!L)R(N-^/G__\'J&S'2`860
M]___$964]___BY60]___#ZS9`HN%^/G__\'K`C';B96P^O__BY7\^?__#Z3"
M'HN5I/[__\'@'@G!BX6@_O__!:'KV6Z)A8CW__^+A5#[__^#T@`!M8CW__^+
MM;#Z__^)E8SW__\1O8SW__\QTC':,<B+O;3Z__\SA?#[__\QV@&%B/?__Q&5
MC/?__XN%L/K__P^D]P6+E;3Z___!Y@6+O?3[___'A03]__\`````#ZS0&PGP
MB[7P^___P>H;,=(!A8CW__\1E8SW__^+E8CW__\/K/X"BX7P^___P>\",?^)
ME0#]__^+E?3[__\/I,(>BY6L_O__P>`>"<:+A:C^__\%H>O9;H/2`(F%@/?_
M_XN%4/O__XF5A/?__XN55/O__P&%@/?__XGP$96$]___B?HQVC'(,=HSA;#Z
M__\!A8#W__\1E83W__^+A0#]__^+E03]___'A7S\__\`````#ZS0&\'J&XF%
ML/3__XN%`/W__XF5M/3__XN5!/W__P^DP@7!X`6)A7CW__^+A;#T__\+A7CW
M__^)E7SW__\QT@&%@/?__Q&5A/?__XN5@/?__XN%L/K__XF5>/S__XN5M/K_
M_P^LT`+!Z@*)A7#W__^+A;#Z__^)E73W__^+E;3Z__\/I,(>P>`>B86H]/__
MB96L]/__BY5P]___QX6\^O__``````G"BX5T]___"X6L]/__B96X^O__B95H
M]___BY6T_O__B85L]___BX6P_O__!=R\&X^)A6#W__^+A;CZ__^#T@`!C6#W
M__^+C;CZ__^)E63W__\1G63W__\)\#'2(X4`_?__"?HA\2':(?L)V@G(BYU\
M_/__`85@]___$95D]___BXUX_/__BY5\_/__BX5X_/__#Z3+!<'A!0^LT!L)
MR,'J&S'2`85@]___$95D]___BY5@]___B958^___BY4$_?__BX4`_?__QX5<
M^___`````,>%#/W__P`````/K-`"P>H"B858]___BX4`_?__B95<]___BY4$
M_?__BXU8]___#Z3"'HN5O/[__\'@'@G!BX6X_O__B8T(_?__!=R\&X^)A5#W
M__^#T@")R`&U4/?__XF55/?__Q&]5/?__S'2(XVX^O__"=(+A;CZ__\QVR.%
M>/S__R'Z(=L)VHN=7/O__PG(BXU8^___`850]___$954]___BX58^___BY5<
M^___#Z3+!<'A!0^LT!L)R,'J&S'2`850]___$954]___BY50]___B[U\_/__
MBX5X_/__B[5X_/__B94`^O__BY5\_/__BXT(_?__QX4$^O__``````^L_@(/
MI,(>BY7$_O__P>`>"<:+A<#^___![P(Q_P7<O!N/B85(]___BX6X^O__@](`
M`85(]___BX4(_?__B95,]___BY6\^O__$95,]___,=()^C';"?`A\2.%6/O_
M_R'[(?H)VHN=!/K__PG(BXT`^O__`85(]___$95,]___BX4`^O__BY4$^O__
M#Z3+!<'A!0^LT!L)R,'J&S'2`85(]___$95,]___BY5(]___BX58^___QX7\
M^___`````,>%9/O__P````")E?C[__^+E5S[__\/K-`"P>H"B85`]___BX58
M^___B95$]___BY5<^___BXU`]___#Z3"'HN5S/[__\'@'@G!BX7(_O__B8U@
M^___!=R\&X^)A3CW__^#T@"+A0C]__\!A3CW__^)R(F5//?__XN5#/W__Q&5
M//?__PGP,=(QVR.%`/K__PGZ(?$A^R'Z"=H)R(N=_/O__P&%./?__Q&5//?_
M_XN-^/O__XN5_/O__XN%^/O__P^DRP7!X04/K-`;"<C!ZALQT@&%./?__Q&5
M//?__XN5./?__XN%`/K__\>%Q/K__P````#'A0SZ__\`````B97`^O__BY4$
M^O__#ZS0`L'J`HF%,/?__XN%`/K__XF5-/?__XN5!/K__XN-,/?__P^DPAZ+
ME=3^___!X!X)P8N%T/[__XF-"/K__P7<O!N/B84H]___@](`B<@!M2CW__^)
ME2SW__\1O2SW__\QTB.-8/O__PG2"X5@^___,=LCA?C[__\A^B';"=J+G<3Z
M__\)R(N-P/K__P&%*/?__Q&5+/?__XN%P/K__XN5Q/K__P^DRP7!X04/K-`;
M"<C!ZALQT@&%*/?__Q&5+/?__XN5*/?__XN]_/O__XN%^/O__XNU^/O__XF5
M$/W__XN5_/O__XN-"/K__\>%%/W__P`````/K/X"#Z3"'HN5W/[__\'@'@G&
MBX78_O__P>\",?\%W+P;CXF%(/?__XN%8/O__X/2``&%(/?__XN%"/K__XF5
M)/?__XN59/O__Q&5)/?__S'2"?HQVPGP(?$CA<#Z__\A^R'Z"=J+G13]__\)
MR(N-$/W__P&%(/?__Q&5)/?__XN%$/W__XN5%/W__P^DRP7!X04/K-`;"<C!
MZALQT@&%(/?__Q&5)/?__XN5(/?__XN%P/K__\>%A/S__P````#'A<SZ__\`
M````B96`_/__BY7$^O__#ZS0`L'J`HF%&/?__XN%P/K__XF5'/?__XN5Q/K_
M_XN-&/?__P^DPAZ+E>3^___!X!X)P8N%X/[__XF-R/K__P7<O!N/B840]___
M@](`BX4(^O__`840]___B<B)E13W__^+E0SZ__\1E13W__\)\#'2,=LCA1#]
M__\)^B'Q(?LA^@G:"<B+G83\__\!A1#W__\1E13W__^+C8#\__^+E83\__^+
MA8#\__\/I,L%P>$%#ZS0&PG(P>H;,=(!A1#W__\1E13W__^+E1#W__^+A1#]
M___'A6S[__\`````QX4<_?__`````(F5:/O__XN5%/W__P^LT`+!Z@*)A0CW
M__^+A1#]__^)E0SW__^+E13]__^+C0CW__\/I,(>BY7L_O__P>`>"<&+A>C^
M__^)C1C]__\%W+P;CXF%`/?__X/2`(G(`;4`]___B94$]___$;T$]___,=(C
MC<CZ__\)T@N%R/K__S';(X6`_/__(?HAVPG:BYUL^___"<B+C6C[__\!A0#W
M__\1E03W__^+A6C[__^+E6S[__\/I,L%P>$%#ZS0&PG(P>H;,=(!A0#W__\1
ME03W__^+E0#W__^+O83\__^+A8#\__^+M8#\__^)E1#Z__^+E83\__^+C1C]
M___'A13Z__\`````#ZS^`@^DPAZ+E?3^___!X!X)QHN%\/[__\'O`C'_!=R\
M&X^)A?CV__^+A<CZ__^#T@`!A?CV__^+A1C]__^)E?SV__^+E<SZ__\1E?SV
M__\QT@GZ,=L)\"'Q(X5H^___(?LA^@G:BYT4^O__"<B+C1#Z__\!A?CV__\1
ME?SV__^+A1#Z__^+E13Z__\/I,L%P>$%#ZS0&PG(P>H;,=(!A?CV__\1E?SV
M__^+E?CV__^+A6C[___'A03\__\`````QX5T^___`````(F5`/S__XN5;/O_
M_P^LT`+!Z@*)A?#V__^+A6C[__^)E?3V__^+E6S[__^+C?#V__\/I,(>BY7\
M_O__P>`>"<&+A?C^__^)C7#[__\%W+P;CXF%Z/;__X/2`(N%&/W__P&%Z/;_
M_XG(B97L]O__BY4<_?__$97L]O__"?`QTC';(X40^O__"?HA\2'[(?H)V@G(
MBYT$_/__`87H]O__$97L]O__BXT`_/__BY4$_/__BX4`_/__#Z3+!<'A!0^L
MT!L)R,'J&S'2`87H]O__$97L]O__BY7H]O__BX40^O__QX74^O__`````,>%
M'/K__P````")E=#Z__^+E13Z__\/K-`"P>H"B87@]O__BX40^O__B97D]O__
MBY44^O__BXW@]O__#Z3"'HN5!/___\'@'@G!BX4`____B8T8^O__!=R\&X^)
MA=CV__^#T@")R`&UV/;__XF5W/;__Q&]W/;__S'2(XUP^___"=(+A7#[__\Q
MVR.%`/S__R'Z(=L)VHN=U/K__PG(BXW0^O__`878]O__$97<]O__BX70^O__
MBY74^O__#Z3+!<'A!0^LT!L)R,'J&S'2`878]O__$97<]O__BY78]O__B[T$
M_/__BX4`_/__B[4`_/__B94@_?__BY4$_/__BXT8^O__QX4D_?__``````^L
M_@(/I,(>BY4,____P>`>"<:+A0C____![P(Q_P7<O!N/B870]O__BX5P^___
M@](``870]O__BX48^O__B974]O__BY5T^___$974]O__,=()^C';"?`A\2.%
MT/K__R'[(?H)VHN=)/W__PG(BXT@_?__`870]O__$974]O__BX4@_?__BY4D
M_?__#Z3+!<'A!0^LT!L)R,'J&S'2`870]O__$974]O__BY70]O__BX70^O__
MQX6,_/__`````,>%W/K__P````")E8C\__^+E=3Z__\/K-`"P>H"B87(]O__
MBX70^O__B97,]O__BY74^O__BXW(]O__#Z3"'HN5%/___\'@'@G!BX40____
MB8W8^O__!=R\&X^)A<#V__^#T@"+A1CZ__\!A<#V__^)R(F5Q/;__XN5'/K_
M_Q&5Q/;__PGP,=(QVR.%(/W__PGZ(?$A^R'Z"=H)R(N=C/S__P&%P/;__Q&5
MQ/;__XN-B/S__XN5C/S__XN%B/S__P^DRP7!X04/K-`;"<C!ZALQT@&%P/;_
M_Q&5Q/;__XN5P/;__XN%(/W__\>%?/O__P````#'A2S]__\`````B95X^___
MBY4D_?__#ZS0`L'J`HF%N/;__XN%(/W__XF5O/;__XN5)/W__XN-N/;__P^D
MPAZ+E1S____!X!X)P8N%&/___XF-*/W__P7<O!N/B86P]O__@](`B<@!M;#V
M__^)E;3V__\1O;3V__\QTB.-V/K__PG2"X78^O__,=LCA8C\__\A^B';"=J+
MG7S[__\)R(N->/O__P&%L/;__Q&5M/;__XN%>/O__XN5?/O__P^DRP7!X04/
MK-`;"<C!ZALQT@&%L/;__Q&5M/;__XN5L/;__XN]C/S__XN%B/S__XNUB/S_
M_XF5(/K__XN5C/S__XN-*/W__\>%)/K__P`````/K/X"#Z3"'HN5)/___\'@
M'@G&BX4@____P>\",?\%W+P;CXF%J/;__XN%V/K__X/2``&%J/;__XN%*/W_
M_XF5K/;__XN5W/K__Q&5K/;__S'2"?HQVPGP(?$CA7C[__\A^R'Z"=J+G23Z
M__\)R(N-(/K__P&%J/;__Q&5K/;__XN%(/K__XN5)/K__P^DRP7!X04/K-`;
M"<C!ZALQT@&%J/;__Q&5K/;__XN5J/;__XN%>/O__\>%#/S__P````#'A83[
M__\`````B94(_/__BY5\^___#ZS0`L'J`HF%H/;__XN%>/O__XF5I/;__XN5
M?/O__XN-H/;__P^DPAZ+E2S____!X!X)P8N%*/___XF-@/O__P7<O!N/B868
M]O__@](`BX4H_?__`868]O__B<B)E9SV__^+E2S]__\1E9SV__\)\#'2,=LC
MA2#Z__\)^B'Q(?LA^@G:"<B+G0S\__\!A9CV__\1E9SV__^+C0C\__^+E0S\
M__^+A0C\__\/I,L%P>$%#ZS0&PG(P>H;,=(!A9CV__\1E9SV__^+E9CV__^+
MA2#Z___'A2SZ__\`````BYTL^O__QX7D^O__`````(F5X/K__XN5)/K__P^L
MT`+!Z@*)A9#V__^+A2#Z__^)E93V__^+E23Z__^+C9#V__\/I,(>BY4T____
MP>`>"<&+A3#___^)C2CZ__\%W+P;CX/2`(F%B/;__XG(`;6(]O__B96,]O__
MBY4L^O__$;V,]O__(XV`^___(YV$^___"X6`^___"Y6$^___(X4(_/__(Y4,
M_/__"<@)V@&%B/;__Q&5C/;__XN-X/K__XN5Y/K__XN%X/K__XN=Y/K__XN]
M#/S__XNU"/S__P^LT!L/I,L%BYTL^O__P>$%"<B+C2CZ___!ZALQT@&%B/;_
M_Q&5C/;__XN5B/;__P^L_@*+A0C\___![P(Q_\>%-/W__P````")E3#]__^+
ME0S\__\/I,(>BY4\____P>`>"<:+A3C___\%W+P;CXF%@/;__X/2`(N%@/O_
M_P&%@/;__XN%*/K__XF5A/;__XN5A/O__Q&5A/;__R'QBY4L^O__(?L)\".%
MX/K__PGZ(Y7D^O__"<@)V@&%@/;__Q&5A/;__XN-,/W__XN5-/W__XN%,/W_
M_XN=-/W__\>%E/S__P````#'A>SZ__\`````#ZS0&P^DRP7!X04)R,'J&S'2
M`86`]O__$96$]O__BY6`]O__BX7@^O__B960_/__BY7D^O__#ZS0`L'J`HF%
M>/;__XN%X/K__XF5?/;__XN5Y/K__XN->/;__P^DPAZ+E43____!X!X)P8N%
M0/___XF-Z/K__P7<O!N/B85P]O__@](`BX4H^O__`85P]O__B<B)E73V__^+
ME2SZ__\1E73V__\)\#'2,=LCA3#]__\)^B'Q(?LA^@G:"<B+G93\__\!A7#V
M__\1E73V__^+C9#\__^+E93\__^+A9#\___'A8S[__\`````#Z3+!<'A!0^L
MT!L)R,'J&S'2`85P]O__$95T]O__BY5P]O__BX4P_?__QX4\_?__`````(F5
MB/O__XN5-/W__P^LT`+!Z@*)A6CV__^+A3#]__^)E6SV__^+E33]__^+C6CV
M__\/I,(>BY5,____P>`>"<&+A4C___^)C3C]__\%W+P;CXF%8/;__X/2`(G(
M`;5@]O__B95D]O__$;UD]O__,=(CC>CZ__\)T@N%Z/K__S';(X60_/__(?HA
MVXNU4/___PG:BYV,^___"<B+C8C[__\!A6#V__\1E63V__^+A8C[__^+E8S[
M__\/I,L%P>$%BYV4_/__QX4T^O__``````^LT!L)R(N-D/S__\'J&S'2`85@
M]O__$95D]O__BY5@]O__#ZS9`HN%D/S__\'K`C';B94P^O__BY64_/__#Z3"
M'HN5-/K__\'@'@G!BX4X_?__@<;6P6+*`[7H^O__,<@SA8C[__\!QHN%,/K_
M_P^LT!O!ZAN)A:#T__^)E:3T__^+A3#Z__^+E33Z__^+O8S[___'A13\__\`
M````#Z3"!<'@!8F%6/;__XN%H/3__PN%6/;__XF57/;__XN5C/O__P'&BX6(
M^___B;40_/__B[6(^___#Z3"'HN57/___P^L_@+!X!X)QHN%6/___\'O`C'_
M!=;!8LJ)A5#V__^#T@"+A3C]__\!A5#V__^)\(F55/;__XN5//W__Q&55/;_
M_XGZ,=HQR#':,X4P^O__`850]O__$954]O__BX40_/__BY44_/__#ZS0&\'J
M&XF%F/3__XN%$/S__XF5G/3__XN5%/S__P^DP@7!X`6)A4CV__^+A9CT__\+
MA4CV__^)E4SV__\QT@&%4/;__Q&55/;__XN54/;__XN%,/K__\>%]/K__P``
M``#'A3SZ__\`````B97P^O__BY4T^O__#ZS0`L'J`HF%0/;__XN%,/K__XF5
M1/;__XN5-/K__P^DPAZ)E93T__^+E4#V___!X!Z)A9#T__\)PHN%1/;__PN%
ME/3__XF5./;__XF5./K__XN59/___XF%//;__XN%8/___P76P6+*B84P]O__
M@](``8TP]O__B94T]O__$9TT]O__,=*+A3CZ__\Q^C':BXWP^O__BYWT^O__
MQX5$_?__`````#'P,X40_/__`84P]O__$94T]O__BX7P^O__#Z3+!8N5]/K_
M_\'A!8N=%/S__P^LT!L)R(N-$/S__\'J&S'2`84P]O__$94T]O__BY4P]O__
M#ZS9`HN%$/S__\'K`C';B95`_?__BY44_/__#Z3"'HN5;/___\'@'@G!BX5H
M____!=;!8LJ)A2CV__^+A3CZ__^#T@`!M2CV__^)E2SV__\1O2SV__\QTC':
M,<@QVC.%\/K__P&%*/;__Q&5+/;__XNU0/W__XN51/W__XN%0/W__XN]1/W_
M_\>%G/S__P`````/K-`;#Z3W!8N]]/K__\'F!0GPB[7P^O__P>H;,=(!A2CV
M__\1E2SV__^+E2CV__\/K/X"BX7P^O__P>\",?^)E9C\__^+E?3Z__\/I,(>
MBY5T____P>`>"<:+A7#___\%UL%BRHF%(/;__X/2`(N%./K__P&%(/;__XGP
MB94D]O__BY4\^O__$94D]O__B?HQVC'(,=HSA4#]__\!A2#V__\1E23V__^+
ME9S\__^+A9C\___'A93[__\`````#ZS0&\'J&XF%B/3__XN%F/S__XF5C/3_
M_XN5G/S__P^DP@7!X`6)A1CV__^+A8CT__\+A1CV__^)E1SV__\QT@&%(/;_
M_Q&5)/;__XN5(/;__XN%0/W__XF5D/O__XN51/W__P^LT`+!Z@*)A1#V__^+
MA4#]__^)E13V__^+E43]__\/I,(>B96$]/__BY40]O__P>`>B86`]/__"<*+
MA13V__\+A83T__^)E0CV__^)E4C]__^)A0SV___'A4S]__\`````BX5X____
MBY5\____QX5$^O__``````76P6+*B84`]O__BX5(_?__@](``8T`]O__BXV0
M^___B94$]O__$9T$]O__,=(Q^C'P,=J+G93[__\SA9C\__\!A0#V__\1E03V
M__^+A9#[__\/I,L%BY64^___P>$%BYV<_/__#ZS0&PG(BXV8_/__P>H;,=(!
MA0#V__\1E03V__^+E0#V__\/K-D"BX68_/__P>L",=N)E4#Z__^+E9S\__\/
MI,(>BU6$P>`>"<&+18`%UL%BRHF%^/7__XN%2/W__X/2``&U^/7__XNU0/K_
M_XF5_/7__Q&]_/7__S'2,=HQR(N]1/K__S.%D/O__S':`87X]?__$97\]?__
MBX5`^O__#Z3W!8N51/K__\'F!8N]E/O__\>%'/S__P`````/K-`;"?"+M9#[
M___!ZALQT@&%^/7__Q&5_/7__XN5^/7__P^L_@*+A9#[___![P(Q_XF5&/S_
M_XN5E/O__P^DPAZ+58S!X!X)QHM%B`76P6+*@](`B87P]?__BX5(_?__B97T
M]?__BY5,_?__`87P]?__B?`1E?3U__^)^C':,<@QVC.%0/K__P&%\/7__Q&5
M]/7__XN%&/S__XN5'/S__\>%_/K__P`````/K-`;P>H;B85X]/__BX48_/__
MB95\]/__BY4<_/__#Z3"!<'@!8F%Z/7__XN%>/3__PN%Z/7__XF5[/7__S'2
M`87P]?__$97T]?__BY7P]?__BX5`^O__B97X^O__BY5$^O__#ZS0`L'J`HF%
MX/7__XN%0/K__XF5Y/7__XN51/K__P^DPA[!X!Z)A7#T__^)E73T__^+E>#U
M___'A4SZ__\`````"<*+A>3U__\+A73T__^)E4CZ__^)E=CU__^+592)A=SU
M__^+19`%UL%BRHF%T/7__XN%2/K__X/2``&-T/7__XN-^/K__XF5U/7__Q&=
MU/7__S'2,?HQ\#':BYW\^O__,X48_/__`870]?__$974]?__BX7X^O__#Z3+
M!8N5_/K__\'A!0^LT!L)R,'J&S'2`870]?__$974]?__BY70]?__B950_?__
MBYT<_/__BX48_/__BXT8_/__BY4<_/__QX54_?__`````,>%I/S__P`````/
MK-D"#Z3"'HM5G,'@'@G!BT68P>L",=L%UL%BRHF%R/7__XN%2/K__X/2``&U
MR/7__XNU4/W__XF5S/7__Q&]S/7__S'2,=HQR(N]5/W__S.%^/K__S':`87(
M]?__$97,]?__BX50_?__#Z3W!8N55/W__\'F!8N]_/K__P^LT!L)\(NU^/K_
M_\'J&S'2`87(]?__$97,]?__BY7(]?__#ZS^`HN%^/K__\'O`C'_B96@_/__
MBY7\^O__#Z3"'HM5I,'@'@G&BT6@!=;!8LJ)A<#U__^#T@"+A4CZ__\!A<#U
M__^)\(F5Q/7__XN53/K__Q&5Q/7__XGZ,=HQR#':,X50_?__`87`]?__$97$
M]?__BX6@_/__BY6D_/__QX6<^___``````^LT!O!ZAN)A6CT__^+A:#\__^)
ME6ST__^+E:3\__\/I,(%P>`%B86X]?__BX5H]/__"X6X]?__B96\]?__,=(!
MA<#U__\1E<3U__^+E<#U__^+A5#]__^)E9C[__^+E53]__\/K-`"P>H"B86P
M]?__BX50_?__B96T]?__BY54_?__QX5<_?__``````^DPAZ)E63T__^+E;#U
M___!X!Z)A6#T__\)PHN%M/7__PN%9/3__XF56/W__XF5J/7__XM5K(F%K/7_
M_XM%J`76P6+*B86@]?__BX58_?__@](``8V@]?__BXV8^___B96D]?__$9VD
M]?__,=(Q^C'P,=J+G9S[__\SA:#\__\!A:#U__\1E:3U__^+A9C[__\/I,L%
MBY6<^___P>$%#ZS0&PG(P>H;,=(!A:#U__\1E:3U__^+E:#U__^+G:3\__^+
MA:#\__^+C:#\__^)E5#Z__^+E:3\___'A53Z__\`````#ZS9`@^DPAZ+5;3!
MX!X)P8M%L,'K`C';!=;!8LJ)A9CU__^+A5C]__^#T@`!M9CU__^+M5#Z__^)
ME9SU__\1O9SU__\QTC':,<B+O53Z__\SA9C[__\QV@&%F/7__Q&5G/7__XN%
M4/K__P^D]P6+E53Z___!Y@4/K-`;"?#!ZALQT@&%F/7__Q&5G/7__XN5F/7_
M_XF5(/S__XN]G/O__XN%F/O__XNUF/O__XN5G/O__\>%)/S__P`````/K/X"
M#Z3"'HM5O,'@'@G&BT6XP>\",?\%UL%BRHF%D/7__X/2`(N%6/W__P&%D/7_
M_XGPB964]?__BY5<_?__$964]?__B?HQVC'(,=HSA5#Z__\!A9#U__\1E93U
M__^+A2#\__^+E23\__\/K-`;P>H;B858]/__BX4@_/__B95<]/__BY4D_/__
M#Z3"!<'@!8F%B/7__XN%6/3__PN%B/7__XF5C/7__S'2`860]?__$964]?__
MBY60]?__BX50^O__QX4$^___`````,>%7/K__P````")E0#[__^+E53Z__\/
MK-`"P>H"B86`]?__BX50^O__B96$]?__BY54^O__#Z3"'HF55/3__XN5@/7_
M_\'@'HF%4/3__PG"BX6$]?__"X54]/__B958^O__B95X]?__BU7$B85\]?__
MBT7`!=;!8LJ)A7#U__^+A5CZ__^#T@`!C7#U__^)E73U__\1G73U__\QTC'Z
M,?`QVC.%(/S__P&%</7__Q&5=/7__XN5!/O__XN-`/O__XN%`/O__XN=!/O_
M_\>%9/W__P`````/K-`;#Z3+!8N=)/S__\'A!0G(BXT@_/__P>H;,=(!A7#U
M__\1E73U__^+E7#U__\/K-D"BX4@_/__P>L",=N)E6#]__^+E23\__\/I,(>
MBU7,P>`>"<&+1<@%UL%BRHF%:/7__XN%6/K__X/2``&U:/7__XNU8/W__XF5
M;/7__Q&];/7__S'2,=HQR(N]9/W__S.%`/O__S':`85H]?__$95L]?__BX5@
M_?__#Z3W!8N59/W__\'F!0^LT!L)\,'J&S'2`85H]?__$95L]?__BY5H]?__
MB[T$^___BX4`^___B[4`^___B96H_/__BY4$^___QX6L_/__``````^L_@(/
MI,(>BU74P>`>"<:+1=#![P(Q_P76P6+*B85@]?__@](`BX58^O__`85@]?__
MB?")E63U__^+E5SZ__\1E63U__^)^C':,<@QVC.%8/W__P&%8/7__Q&59/7_
M_XN%J/S__XN5K/S__P^LT!O!ZAN)A4CT__^+A:C\__^)E4ST__^+E:S\__\/
MI,(%P>`%B858]?__BX5(]/__"X58]?__B95<]?__,=(!A6#U__\1E63U__^+
ME6#U__^+A6#]___'A:3[__\`````QX5L_?__`````(F5H/O__XN59/W__P^L
MT`+!Z@*)A5#U__^+A6#]__^)E53U__^+E63]__\/I,(>B95$]/__BY50]?__
MP>`>B85`]/__"<*+A53U__\+A43T__^)E4CU__^)E6C]__^+5=R)A4SU__^+
M1=@%UL%BRHF%0/7__X/2``&-0/7__XF51/7__Q&=1/7__S'2BX5H_?__,?HQ
MVHN-H/O__XN=I/O__\>%9/K__P````"+O63Z__\Q\#.%J/S__P&%0/7__Q&5
M1/7__XN%H/O__P^DRP6+E:3[___!X07'A;3\__\`````#ZS0&PG(P>H;,=(!
MA4#U__\1E43U__^+E4#U__^+A:C\__^)E6#Z__^+E:S\__\/K-`"P>H"B84X
M]?__BX6H_/__B94\]?__BY6L_/__BXTX]?__#Z3"'HN59/K__\'@'@G!B8VP
M_/__BTW@BX6P_/__@<'6P6+*`?&+M6#Z__\SA6C]__\SA:#[__\!P8N%8/K_
M_P^D]P7!Y@4/K-`;"?#!ZAL!P8F-*/S__XN=I/O__XN%H/O__XN-H/O__XN5
MI/O__XMUZ,>%+/S__P`````/K-D"#Z3"'HN5+/S__\'@'@G!BX6P_/__P>L"
M@<;6P6+*`[5H_?__,<@SA6#Z__\!QHN%*/S__P^LT!O!ZAN)A3CT__^+A2C\
M__^)E3ST__^+E2S\__\/I,(%P>`%B84P]?__BX4X]/__"X4P]?__B94T]?__
M`<:)\(NUE/G__P.%(/7__\=&!`````")!HN]*/S__P%^",=&#`````"+E63Z
M__^+M6#Z__^+A6#Z__^+O63Z__\/K-`"#Z3W'L'F'@GPB[64^?__P>H"`480
M`4X8QT84`````,=&'`````"+O;#\__\!?B#'1B0`````@<2\"P``6UY?7<.-
M="8`C;PG`````%6)Y8/L*(7`B7W\B<>)7?2)=?B)5>AU#S'`BUWTBW7XBWW\
MB>Q=PZ'P9@4(A<")1>QTY0^V!X3`=43'1?``````BU7LBQJ%VW3.B=:-="8`
MBT7PB7PD!(D<)(E$)`CHR;#__X7`=0N+5?"-!!.`.#UT*8M>!(/&!(7;==3K
MFCP]B?ITMH/"`0^V`H3`=0<I^HE5\.NL/#UUZ^OS*W7L@\`!BU7HP?X"B3+I
M;/___XGV58GE5E.)PXUU](/L$(GRB=CH.O___X7`="^-M@````"+1?2-%(4`
M`````Q7P9@4(@\($BP*%P(E"_'7TB?*)V.@+____A<!UUX/$$%M>7<-5B>6#
M[!B-5?SH\O[__\G#58GE@^P(@ST08`4(_W0'H1!@!0C)P[AW``4(Z-#___^%
MP'0'#[8`A,!U%3'`HQ!@!0BA$&`%",G#C;0F`````#PP#Y7`#[;`Z^.-M@``
M``!5B>6#[`C'!"3_____Z!JP___'1"0$`````,<$)+#C!`CH1K+__\G#D(VT
M)@````!5B>53@^P4H9!B!0B+2`2AL&(%"`^W4!`/M@658@4(9H'B_P&#X'_!
MX@<)PF:)40*AD&(%"(M8!,=$)`0`````QP0D&0(%".CPK___B4,<H9!B!0B+
M4`2AN&(%"(E"(*&08@4(,=*+2`2AB&(%"(7`=`.+4'")422AD&(%"(M`!,=`
M*`````"AD&(%"(M`!,=`&`````"AD&(%"(M0!*&T8@4(B4(L@\046UW#C70F
M`%6)Y5=64X/L?(7`B46,=`6`.`!U"X/$?%M>7UW#C78`B00DZ/2O__^%P(E%
MD'3FD(M%D(D$).@AL?__A<`/A*D```"-6`B_@@`%"/RY`@```(G>\Z9TV;^!
M``4(N0,```")WO.F=,F+18R)!"3H:K'__XD<)(G&Z&"Q__^-1`8"B00DZ*2P
M__^)7"0,B<:+18S'1"0$A``%"(DT)(E$)`CH9['__XU%E(E$)`2)-"3H6*__
M_X/``700#[=%G"4`\```/0!```!T08DT).C[KO__B30DZ).P__^+19")!"3H
M>+#__X7`#X57____BT60B00DZ/6P__^+18R)!"3H2J___X/$?%M>7UW#B?#H
M[_[__^N^C;8`````C;PG`````%6)Y5.)PX/L=(U%G(E$)`2)'"3HI*W__X7`
M=1</MT6D)0#P```]`$```'04/0"@``!T#8/$=#'`6UW#D(UT)@")'"3'1"0$
M`@```.B,KO__A<`/E,"#Q'1;#[;`7<.)]E6)Y5=6B=93@^PLB47<,<"`.CT/
ME,`!QHDT).@\L/__C57PB47@BT7<Z!+\__^%P(G#="J)!"3H(+#__SE%X`^'
MGP````^V!H/&`8@#@\,!A,!U\8/$+#'`6UY?7<.A\&8%"#';N@@```"+"(7)
M=!&#PP&+/)B%_W7VC12="````(L-P&(%"(7)#X4-`0``QP7`8@4(`0```(D4
M).@+K___A<")1=@/A!$!``"A\&8%"(T\G0````")?"0(B40D!(M%V(D$).BA
MKO__BU78B17P9@4(H?!F!0C'1`<$`````(E=\(M5W`^V`H3`#X2C````/#T/
MA)L```"-M@````"#P@$/M@*$P'5[B=`K1=R+3>"+7?"-1`@"P>,"B00D`QWP
M9@4(Z(*N__^%P(D##X2)````BU7PH?!F!0B+#)"+5=P/M@*$P(@!=!T\/709
MB=#K"(/``8#Z/70-#[90`8/!`832B!%UZ\8!/8G*C78`#[8&@\8!B$(!@\(!
MA,!U\.G/_O__/#T/A7/___^-=@#I=?___S'`Z7/___^)5"0$B00DZ$2L__^%
MP*/P9@4(=`R-/)T`````Z1?___^#Q"RX_____UM>7UW#C;8`````58GE5[^4
M``4(5E.#[$R-7=C'1=B4``4(QT7<B@`%",=%X)<`!0C'1>2-``4(QT7HD@`%
M",=%[*0`!0C'1?``````ZQB+50B)^.CB_?__BWL$@\,$A?\/A)\```")^.@-
M^___A<")QG3;@#@`=-:+10B)-"2)1"0$Z*^L__^%P'7-BU4(B10DZ`"N__^)
M1="AA`(%"(D$).CPK?__BU70B30DC40"`8E%S.C>K?__`T7,B00DZ".M__^+
M50B)="00QT0D!,,!!0B)5"0(B47(H80"!0B)1"0,BT7(B00DZ-FM__^+5<B)
M^.A#_?__BWL$@\,$A?\/A6'___^#Q$Q;7E]=PXVV`````(V\)P````!5B>57
M5H/L,*%H8@4(B47T,<"A7`(%"(E%TJ%@`@4(B476H60"!0B)1=JA:`(%"(E%
MWJ%L`@4(B47BH7`"!0B)1>:A=`(%"(E%ZJ%X`@4(B47N#[<%?`(%"&:)1?*X
MKP`%".BI^?__N+@`!0CHG_G__[C```4(Z)7Y__^XR0`%".B+^?__N-``!0CH
M@?G__[C@``4(Z'?Y__^X[``%".AM^?__N'<`!0CH8_G__[CU``4(Z%GY__^X
M_P`%".A/^?__N`D!!0CH1?G__[@6`04(Z#OY__^X'P$%".@Q^?__N"H!!0CH
M=_G__X7`=`R)PKCU``4(Z"?\__^X.P$%".A=^?__A<!T#(G"N$T!!0CH#?S_
M_[A8`04(Z$/Y__^%P'0OB<*X[``%".CS^___NH0!!0BXT``%".CD^___BT7T
M,P5H8@4(=4:#Q#!>7UW#B?:X:`$%".@&^?__A<!T#HG"N'<`!0CHMOO__^O!
M_(UUX[]Y`04(N0H```#SIG6OC57MN'<`!0CHE?O__^N@Z*JK__^-M"8`````
MC;PG`````%6)Y8/L".AQJ___B00DZ+FJ__\QTH7`=`*+$,F)T,.058GE@^P8
MB5WTBUT(B77XB7W\A=MT"0^V.XGXA,!U&,=%"((`!0B+7?2+=?B+??R)[%WI
MI:C__XD<).A]J___`=B-4/\YTW,FBPV``@4(#[9`_P^V,8GQ.,AT#.LVC78`
M#[8*.,%U;(/J`3G3<O(YVG4PBQ6``@4(B?@Z`G2ABPV``@4(B4T(ZYV-M"8`
M````#[8"B?$XP735@^H!.=-R\.O,@^H!.=-S#8L-@`(%"`^V`CH!=.PIVC')
MC4("/0`$``!V$XM=](G(BW7XBWW\B>Q=PXG(Z[R-0@&)1"0(B5PD!,<$).!B
M!0CHKJC__[G@8@4(Z\^-="8`C;PG`````%6)Y8/L&(E=^(M="(EU_(D<).CI
M_O__B00DZ$&L__^)QNB*]___A<!T"87;=`6`.P!U#8M=^(MU_(GL7<.-=@#'
M1"0$A@$%"(DT).@,J?__.<9UWXMU_(G8BUWXB>Q=Z7SX__^-M@````"-OP``
M``"-3"0$@^3P_W'\C4$(58GE5XG/5E-1@^P8B40D"(U!!(E$)`2)#"3H(*C_
M_X`]C&(%"``/A!X!``"`#8UB!0@#,=*+#U*-0050WRPD@\0(W`587P4(W05@
M7P4(V<G:Z=_@G@^'2`$``(T$C10```")!"3H-:K__Z/L9@4(B<&+1P2+`,=!
M!(L!!0B)`:$,8`4(QT$,C@$%"(E!",<%Z&8%"`0```"+'X/[`0^.W0```(MW
M!(U!_+H!````B47LB?:+!):)1)$,@\(!.=-_\HM%[,=$F!``````QT0D$```
M``")3"0,BP?'1"0$L/\$"(/``XE$)`BAX&8%"(D$).CIIO__A<")PW1PH>!F
M!0B)!"3H%JC__[C@``4(Z!#V__^%P'0@H>!F!0B)!"3HBZG__^A6J?__@\08
MB=A96UY?78UA_,.AY&8%"(7`=$N)!"3H._[__^O-Z%"H__^%P*/@9@4(=%^)
M!"3H/Z;__\8%8&(%"`#IP/[__Z'@9@4(B00DZ":G__^)P^E\____C4'\B47L
MZ3;___^X[``%".B.]?__A<"CY&8%"'6BZ73____'1"0$F&(%",<$)!`"!0CH
M2*7__\<$)`$```#HK*?__U6)Y5=64X'LG`0``(M]"*%H8@4(B47P,<"X[``%
M"(M=#.@Z]?__BS6``@4(B3PDB70D!(F%@/O__^C>IO__A<!T*(GZN`D!!0CH
MTO?__XM5\#,5:&(%"(GX#X5X`0``@<2<!```6UY?7<.)/"3H"JC__XL5A`(%
M"(D<)(E4)`2)A7S[___H`J;__X7`B<-TLHN%?/O__X/``8F%>/O__Y"`.P!U
M!;N"``4(BX6`^___A<!T&HN5@/O__XE<)`2)%"3H9J;__X7`#X2Q````B1PD
MZ*:G__^)P0^V1`/_.@9U%8T4"P^V0OZ#Z0'&0O\`@^H!.@9T[HN%>/O__P'(
M/?\#```/CSG___^-E?#[__^)%"2)?"00B70D#(E<)`C'1"0$PP$%".B!I___
MC860^___B40D!(V%\/O__XD$).AII?__A<!U$P^WA9C[__\E`/```#T`@```
M=#Z+%80"!0C'!"0`````B50D!.@<I?__B<.%VP^%)O___^G#_O__H80"!0C'
M!"0`````B40D!.CXI/__B</KVHV5\/O__\=$)`0!````B10DZ.ZD__^%P'6H
MC97P^___N`D!!0CH7O;__XV%\/O__XD$).C,H___B<?I=_[__^A@IO__C70F
M`%6)Y5=64X'LK($``(M%"(L5:&(%"(E5[#'2QX48?___D0$%",>%''___Y8!
M!0B)A7Q^__^X[``%",>%('___P````#H.//__X7`B<-T"8`X``^%H@(``.AD
M^O__O@$```"-O1A___^%P(G##X3I`0``B1PDZ".F__^-1``!B00DZ&>E__^)
MA7A^__^`.P!T)(G&#[8#@\,!B30D@\8"QT0D!*8!!0B)1"0(Z!VF__^`.P!U
MWKA-`04(C;4`?___QX4`?___30$%",>%!'___T8!!0C'A0A___^K`04(QX4,
M?___8P$%",>%$'___[,!!0C'A11___\`````ZQ&-=@"+1@2#Q@2%P`^$=P$`
M`.AM\O__A<")PW3G@#@`=.*)]NB[]/__A<!TUXD<).B+HO__A<")QP^$3`$`
M`(D\).A9I?__BXUX?O__B0PDB</H2:7__XVT`P0$``")-"3HBJ3__XL5@`(%
M"(E\)`C'1"00A@$%",=$)`3!`04(B50D#(F%='[__XN%>'[__XN-='[__XE$
M)!2)#"3H+J7__XN]='[__\=$)`3``0``B3PDZ"BD__^#P`$/A%<!``"+C71^
M__^-A:!^__^)1"0$B0PDZ,>A__^%P'47#[>%J'[__R4`\```/0!````/A'$!
M``"+O71^__^+E7Q^__^)?"0,BP+'1"0$Q`(%"(E$)`BAK&(%"(D$).A1H?__
MQX6`?O__`````(M-[#,-:&(%"(N%@'[__P^%T0(``('$K($``%M>7UW#B00D
MZ&^A__^)PX/&`87;#X47_O__BT2W_(7`#X2;`@``Z!7Q__^%P'3@@#@`==&#
MQ@&%VW3?D(UT)@#I[/W__S'_@#VW`04(`+NW`04(QX4D?___MP$%"(VU)'__
M_\>%*'___X(`!0C'A2Q___\`````=2GI??[__XGVA?\/A7/^__^+7@2%VXUV
M``^$9?[__X/&!(`[``^$6?[__XG8Z/?R__^%P'33B1PDZ,>@__^)Q^O'B00D
MZ`_U__^)'"3HLZ#__XF%@'[__^D1____Z`.B__^#.!$/A)O^___H]:'__XN5
M?'[__XL`B7PD#(E$)!"+`L=$)`2(`@4(B40D"*&L8@4(B00DZ!J@___'A8!^
M__\`````Z<3^__^+G:Q^___HT*+__SG##X5\_O__#[>%J'[__R7_`0``/<`!
M```/A67^__^)-"3H6:+__XF%@'[__[B-``4(Z-WO__^%P`^$:@$``(D$).@)
MH/__B[U\?O__B40D!(L'B00DZ%GZ__^%P(F%;'[__P^$0`$``(N5;'[__XD4
M).BYHO__@_@#B<,/C[T&``#HG>___X7`=22+A6Q^___'1"0$`````(D$).B/
MH?__A<")A81^__\/A0T!``"ZA`$%"+AW``4(Z!;R__\QV^A+HO__BPV``@4(
MB[UT?O__QT0D%!D"!0C'1"0$XP$%"(E,)`R)?"0(B40D$(N%@'[__XD$).AE
MHO__ZTSHKJ#__X,X$75=Z`2B__^+%8`"!0B#PP&+C71^__^+O8!^___'1"08
M&0(%"(E<)!2)5"0,B40D$(E,)`C'1"0$\0$%"(D\).@7HO__BX6`?O__QT0D
M!,`!``")!"3H$:'__X/``729BY5T?O__B10DZ$ZA__^+E8!^__^X[``%".A2
M\?__BXV`?O__B0PDZ!3S___I)/W__[N?`04(Z6;[__^0C70F`.A'H?__BX5\
M?O__BP")A6Q^___IK?[__\=$)`P"````QT0D!.[____'1"0(_____XD$).CD
MG___BXV$?O__C94P?___QT0D"`8```")5"0$B0PDZ%2A__^`O3!___\`=0V`
MO3%___]##X39!0``BY6$?O__QT0D#`````#'1"0$`````,=$)`@`````B10D
MZ(B?___'A3#___\!(T5GQX4T____`````,>%./___XFKS>_'A3S___\`````
MQX5`_____MRZF,>%1/___P````#'A4C___]V5#(0QX5,____`````,>%4/__
M__#ATL/'A53___\`````QX58____`````,>%7/___P````#'A6#___\`````
MQX5D____`````,=%J`````"+O81^__^-C3!____'1"0(`(```(E,)`2)/"3H
M9:#__X7`B86<?O__#XZK`0``BX6<?O__B[58____B[U<____B<+!^A^)A8A^
M__^)E8Q^__\/I,(#P>`#`?`QVSG?B<%R%'<$.<9V#H.%8/___P&#E63___\`
MB8U8____BY6(?O__C;5H____BXV,?O__B9U<____C9TP?___#ZS*'<'I'0&5
M8/___XM5J!&-9/___X72#X2+````Z;<```"+`XF%:/___XM#!(F%;/___XM#
M"(F%</___XM##(F%=/___XM#$(F%>/___XM#%(F%?/___XM#&(E%@(M#'(E%
MA(M#((E%B(M#)(E%C(M#*(E%D(M#+(E%E(M#,(E%F(M#-(E%G(M#.(E%H(M#
M/(/#0(.MG'[__T")1:2-A3#____H!J'__X.]G'[__S\/CVW___^+A9Q^__^)
M7"0$B30DB40D".AOGO__BY6<?O__B56HZ8S^__^+G9Q^__^X0````"G0.<-^
M`HG#C;5H____C006C8TP?___B5PD"(E,)`2)!"3H+Y[__XG8`T6H@_A`B46H
M#X5)_O__C;TP?___C84P____*9V<?O__C1P?Z'B@___I;?___XUV`(D\).A4
MG?__BX5@____BY5D____BYU8____B[5<____B860?O__B964?O__B=B)\@^L
MT`.)P8/A/\'J`XU1`8/Z.,:$*6C___^`#X[0`@``N$`````IT(V4*6G___^)
M%"2-O6C___^)1"0(QT0D!`````#H9)S__XV%,/___^CMG___N0X````QP/SS
MJXN5E'[__XU]V(N%D'[__XA=IP^LT!B(1:#!ZAB+A9!^__^+E91^__\/K-`0
MB$6AP>H0BX60?O__BY64?O__#ZS0",'J"`^VE9!^__^(1:*)V(A5HXGR#ZS0
M&(A%I,'J&(G8B?(/K-`0B$6EP>H0B=B)\@^LT`B(1::-A3#____!Z@CH7)__
M_XN-,/___XUUKXN=-/___XG(B=H/K-`8B$78P>H8B<B)V@^LT!"(1=G!ZA")
MR(G:BYT\____B$W;BXTX____#ZS0"(A%VL'J"(G:B<@/K-`8B$7<P>H8B<B)
MV@^LT!"(1=W!ZA")R(G:BYU$____B$W?BXU`____#ZS0"(A%WL'J"(G:B<@/
MK-`8B$7@P>H8B<B)V@^LT!"(1>'!ZA")R(G:BYU,____B$WCBXU(____#ZS0
M"(A%XL'J"(G:B<@/K-`8B$7DP>H8B<B)V@^LT!"(1>7!ZA")R(G:BYU4____
MB$WGBXU0____#ZS0"(A%YL'J"(G:B<@/K-`8B$7HP>H8B<B)V@^LT!"(1>G!
MZA")R(G:,=L/K-`(B$7JP>H(B$WK#[8$.X/#`8DT)(/&`L=$)`2F`04(B40D
M".AHG/__@_L4==V+/8`"!0B-3:^+A71^__^+E8!^___&1=<`QT0D%!D"!0B)
M3"00B7PD#(E$)`C'1"0$U`$%"(D4).@FG/__Z27Z__^+C6Q^__^Z!0```/R-
M=`'\N,H!!0B)QXG1\Z8/A2+Y__^#^P1T&8N5;'[__XL-@`(%"`^V1!/[.@$/
MA03Y__^+O7Q^__^+7P2%VP^$\_C__XD<).B9F___@_@##X;B^/__C70#_+C/
M`04(_+D%````B<?SI@^%R?C__XF=;'[__^F^^/__N#@````IT(V4*6G___^)
M1"0(QT0D!`````")%"3HFIG__^E&_?__@+TR?___00^%&OK__X"],W___T,/
MA0WZ__^`O31___](#X4`^O__@+TU?___10^%\_G__XN]A'[__\=$)`P"````
MQT0D!,;____'1"0(_____XD\).A[F?__C84P?___B3PDQT0D""D```")1"0$
MZ/&:__^+#8`"!0B-E3!___^+O71^__^+A8!^___'1"04&0(%"(E4)!")3"0,
MB7PD",=$)`34`04(B00DZ,6:___IQ/C__XUT)@!5B>6![#@(``"A:&(%"(E%
M\#'`B5WTC9WO^___B77XB7W\Z$6:___'1"0,`@(%",=$)`0'`@4(B1PDB40D
M".AYFO__A<!Y'#';BU7P,Q5H8@4(B=AU5(M=](MU^(M]_(GL7<.-O>[W___'
M1"0(``0``(E\)`2)'"3H7YK__X7`B<9XQ(U``8D$).A.F?__A<!TM8G#B70D
M"(E\)`2)!"3H6)G__\8$,P#KG^B=F?__D%6)Y5WI1____XVT)@````!5N-``
M!0B)Y5=64X/L',8%E&(%"`'HEN;__X7`=`F`.#$/A+8!``#H).S__\=$)`@+
M````QT0D!`$```#'!"03`@4(Z*28__^%P`^$C@```(M`##'V@SWH9@4(`8MX
M&'YLNP$```#K*8M0#*'L9@4(BP28B50D!(D$).C]E___A<!U2H/&`8/#`3D=
MZ&8%"'X\QT0D"`````")="0$B3PDZ!>9__^%P'0DBP#V0`D$=;?'1"0(`@``
M`,=$)`0`````B00DZ..5__^)PNN>BQ7H9@4(C4+_.?`/A-D```#'1"0(!```
M`,=$)`0!````QP0D&`(%".CRE___A<")PW0DQT0D!!H"!0B+0`R+`(D$).AW
MEO__BT,,BP#V0`I`#X71````QT0D"`0```#'1"0$`0```,<$)"@!!0CHK)?_
M_X7`B<9T([@)`04(Z&#E__^%P`^$SP```(E$)`2+1@R+`(D$).@CEO__N.P`
M!0C&!91B!0@`QP5D8@4(`````.@LY?__A<"CY&8%"'1XQT0D!,`!``")!"3H
M;Y?__X7`=`Z#^!%T"8/X_P^%H0```(/$'%M>7UW#@^H!#XX>____NP$```")
M/"2#PP'H+)7__SD=Z&8%"'_MZ0'___^`>`$`#X1%_O__B?:-O"<`````Z3+^
M__^)!"3H#Y7__XUV`.D?____H>QF!0B)!"3H'O'__X7`H^1F!0AU9<<$)!@#
M!0CH993__^C$_?__A<")PW1"B40D!(M&#(L`B00DZ$F5__^)'"3H$9?__^D9
M____B40D#*'D9@4(B40D"*'L9@4(BP#'!"1D`P4(B40D!.@8E/__H>QF!0B+
M`.G8_O__BT8,BQWL9@4(BP#V0`D$=#Z+0`R)7"0$B00DZ!R4__^)PXM&#(L`
M]D`)!'0\BT`,B40D"*'L9@4(B5PD#(L`QP0D/`,%"(E$)`3HO9/__\=$)`@"
M````QT0D!`````")!"3HQ9/__^NKQT0D"`(```#'1"0$`````(D$).BKD___
MZZV-M@````"-O"<`````58GE@^P8QT0D"!\"!0C'1"0$_)0$",<$)"D"!0CH
M:I3__\G#C;8`````C;\`````58GE@^P8Z,7____'1"00`````,=$)`P9`@4(
MQT0D"!D"!0C'1"0$</P$",<$)$4"!0CHI9/__\G#D)"0D)"0D%6)Y5.#[`2A
M1&$%"(/X_W02,=O_T(N#0&$%"(/K!(/X_W7P@\0$6UW#D)"0@^P,Z%R7__^#
MQ`S#)$9R965"4T0Z(')E;&5N9R\X+C,O;&EB+V-S=2]I,S@V+65L9B]C<G1I
M+E,@,30V,S8Y(#(P,#4M,#4M,3D@,#<Z,S$Z,#9:(&1F<B`D`%!!4E]#3$5!
M3@`N+@`E<R\E<P!,24)0051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!
M5$@`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)
M04Q)6D5$`%!!4E]34$%73D5$`%!!4E]414U0`%!!4E]$14)51P!005)?0T%#
M2$4`4$%27U!23T=.04U%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!
M3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!P87(M`"UE
M`"TM`%5315(`55-%4DY!344`4UE35$5-`"4P,G@`5$5-4$1)4@!435``+W9A
M<B]T;7`O`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S
M=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`9FEL90`O<')O8R\E:2\E<P!!
M4D=6`!@`<&5R;`!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`#H`7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("``````OP$%"%H"!0@E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T:6]N(&]F("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````C
M(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP
M="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM
M+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O
M<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@
M("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@
M("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@
M.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*
M("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S
M(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG
M('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-
M4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL
M:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@
M(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL
M;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E
M>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C
M:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@
M87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@
M(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P
M87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE
M86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@
M("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@
M("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M
M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@
M(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G
M(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B
M)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@
M("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L
M;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M
M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T
M;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA
M;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T
M<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@
M("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.
M5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*
M?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E
M("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O
M:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@
M("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE
M>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X
M=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A
M('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@
M;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E
M:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T
M('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@
M+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@
M+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U
M9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@
M?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![
M>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B
M1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R
M96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY
M("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@
M9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F
M=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968[
M"B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I
M;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@
M:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@
M("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@
M("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I
M;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN
M86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M
M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@
M("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@
M("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S
M96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M
M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA
M;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O
M=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V
M>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@
M(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@
M("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@
M?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]
M"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R
M968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE
M(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@
M("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R
M97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<
M421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U
M<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA
M;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD
M(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F
M:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@
M("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE
M;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@
M("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP
M;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@
M>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@
M("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@
M("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E
M;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@
M?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@
M9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO
M860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H
M87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*
M("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A
M=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@
M9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER
M92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*
M("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E
M7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@
M7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U
M=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL
M93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N
M86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R
M7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE
M*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U
M;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE
M;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P
M=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*
M("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P
M87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N
M7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@
M=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@
M+2UR975S92!04D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P
M<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H
M:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@
M=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@
M('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL
M92`H0$%21U8I('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D
M,2!E<2`G22<I('L*("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L
M("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M32<I('L*("`@("`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@
M("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@
M("`@("1O=70@/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I
M=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M0B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@
M("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@
M("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@
M("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@
M("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ
M1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X:70["B`@
M("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@
M0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U
M9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN
M9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG
M0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@
M("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E
M.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@
M(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O
M<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P
M87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S
M*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@
M("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@
M("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@
M("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I
M;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*
M"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\
M)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!
M4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A
M=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@
M("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@
M("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D[
M"@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z
M('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@
M<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@
M(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M
M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E
M=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I
M8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M
M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@
M("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC
M("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI
M"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*
M("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE
M9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U
M:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I
M<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@
M("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R
M97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@
M("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@
M("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@
M("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@
M("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D
M9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X
M:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O
M875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I
M>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@
M(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E
M<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE
M9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\
M*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z
M.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@
M("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K
M97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*
M"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@
M("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@
M("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2![
M"B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R
M*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ
M6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@
M/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@
M("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I
M.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR
M968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A
M;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H
M1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@
M("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@
M("`@("`@(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PH@("`@("`@("`@("!]"@H@("`@
M("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@
M("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S
M(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M
M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R
M:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@
M(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[
M>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*
M("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*
M("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O
M=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q
M+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U
M;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@
M("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D
M8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@
M("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N
M/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E
M<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^
M8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E
M>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I
M;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T
M:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM[
M"B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG
M?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q
M=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP
M.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N
M;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]
M("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U
M=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*
M("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M
M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@
M("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG
M.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=
M*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@
M("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M
M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@
M("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE
M(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*
M("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*
M("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@
M("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@
M;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%2
M7U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]
M"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\[
M"B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A
M<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A
M<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ
M4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B
M(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@
M;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E
M9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S
M.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q
M=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@
M("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@
M<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@
M(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@
M("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0[
M"B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*("`@(')E<75I<F4@871T
M<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![
M(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P
M='5R92!].PH@("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E
M<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O
M9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L
M<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N
M=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@
M("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@
M("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@
M("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED
M.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@
M(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[
M?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@
M("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@
M("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@
M("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F
M:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X
M+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@
M("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@
M("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A
M9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP
M+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U
M:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@
M("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!]
M.PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I
M9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS
M."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X
M*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@
M(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM
M;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I
M;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@
M("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@
M,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E
M;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D
M<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@
M("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?
M=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H
M)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O
M)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@
M("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P
M=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@
M("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA
M;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D
M:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL
M96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O
M9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*
M("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@
M('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO
M<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T
M=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O
M9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@
M+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@
M('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF
M:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I
M9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?
M5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D
M+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?
M<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M
M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\[
M"@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@
M7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@
M("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O
M<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-
M12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?
M)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%2
M7T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1?
M?3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI
M('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@
M("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T
M:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@
M)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U
M=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*
M("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92![
M"B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@
M>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R
M8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@
M("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@
M9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M"C$["@HC;&EN92`Q,#$Q"@I?7T5.1%]?"@``````````````@/___\]!)$9R
M965"4T0Z(')E;&5N9R\X+C,O;&EB+V-S=2]I,S@V+65L9B]C<G1N+E,@,30V
M,S8Y(#(P,#4M,#4M,3D@,#<Z,S$Z,#9:(&1F<B`D```!&P,[6`````$````(
M-___=```````````````````````````````````````````````````````
M```````````````````9`@4(`````%!A!0BH`P4(_____Q0``````````7I2
M``%\"`$;#`0$B`$``!@````<````C#;__QD`````0PX$0H4"#04`````````
M`0````$````!````'0(```$````G`@```0```#4"```!````0@(```$```!F
M`@``#P```(\#```,````V)($"`T````<``4(!````$2!!`@%````R(H$"`8`
M``!HA`0("@```+,$```+````$````!4``````````P```%AA!0@"````X`$`
M`!0````1````%P```/B0!`@1````B)`$"!(```!P````$P````@```#^__]O
M2)`$"/___V\"````\/__;WR/!`@`````````````````````````````````
M``````````````````````````````#_____`````/____\``````````$Q@
M!0@```````````*3!`@2DP0((I,$"#*3!`A"DP0(4I,$"&*3!`ARDP0(@I,$
M")*3!`BBDP0(LI,$",*3!`C2DP0(XI,$"/*3!`@"E`0($I0$""*4!`@RE`0(
M0I0$"%*4!`ABE`0(<I0$"(*4!`B2E`0(HI0$"+*4!`C"E`0(TI0$".*4!`CR
ME`0(`I4$"!*5!`@BE00(,I4$"$*5!`A2E00(8I4$"'*5!`B"E00(DI4$"**5
M!`BRE00(PI4$"-*5!`CBE00(\I4$"`*6!`@2E@0((I8$"#*6!`A"E@0(4I8$
M"&*6!`ARE@0(@I8$")*6!`BBE@0(LI8$"``````````````````D1G)E94)3
M1#H@<F5L96YG+S@N,R]L:6(O8W-U+VDS.#8M96QF+V-R=#%?<RY3(#(Q-S0W
M,"`R,#$Q+3`Q+3$V(#$P.C0Q.C0W6B!K:6(@)```)$9R965"4T0Z(')E;&5N
M9R\X+C,O;&EB+V-S=2]C;VUM;VXO8W)T8G)A;F0N8R`Q-S0R-3$@,C`P-RTQ
M,BTP-"`Q,CHQ.#HT,UH@:VEB("0`1T-#.B`H1TY5*2`T+C(N,B`R,#`W,#@S
M,2!P<F5R96QE87-E(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N,B`R,#`W
M,#@S,2!P<F5R96QE87-E(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N,B`R
M,#`W,#@S,2!P<F5R96QE87-E(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N
M,B`R,#`W,#@S,2!P<F5R96QE87-E(%M&<F5E0E-$70``+G-H<W1R=&%B`"YI
M;G1E<G``+FYO=&4N04))+71A9P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI
M;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N9&%T80`N
M96A?9G)A;64`+F1Y;F%M:6,`+F-T;W)S`"YD=&]R<P`N:F-R`"YG;W0`+F)S
M<P`N8V]M;65N=```````````````````````````````````````````````
M``````````L````!`````@```!2!!`@4`0``%0```````````````0``````
M```3````!P````(````L@00(+`$``!@```````````````0`````````(0``
M``4````"````1($$"$0!```D`P``!``````````$````!````"<````+````
M`@```&B$!`AH!```8`8```4````!````!````!`````O`````P````(```#(
MB@0(R`H``+,$``````````````$`````````-P```/___V\"````?(\$"'P/
M``#,````!``````````"`````@```$0```#^__]O`@```$B0!`A($```0```
M``4````"````!`````````!3````"0````(```"(D`0(B!```'`````$````
M``````0````(````7`````D````"````^)`$"/@0``#@`0``!`````L````$
M````"````&4````!````!@```-B2!`C8$@``$0``````````````!```````
M``!@`````0````8```#LD@0([!(``-`#``````````````0````$````:P``
M``$````&````P)8$",`6``!<:0`````````````0`````````'$````!````
M!@```!P`!0@<@```#```````````````!`````````!W`````0````(````H
M``4(*(```(]?``````````````@`````````?P````$````"````N%\%"+C?
M```4```````````````$`````````(T````!`````P````!@!0@`X```%```
M````````````!`````````"3`````0````(````48`4(%.```#@`````````
M``````0`````````G0````8````#````3&`%"$S@``#X````!0`````````$
M````"````*8````!`````P```$1A!0A$X0``"```````````````!```````
M``"M`````0````,```!,804(3.$```@```````````````0`````````M```
M``$````#````5&$%"%3A```$```````````````$`````````+D````!````
M`P```%AA!0A8X0``_```````````````!`````0```"^````"`````,```!@
M8@4(8.(``)0$`````````````"``````````PP````$``````````````&#B
M``!C`0`````````````!``````````$````#``````````````##XP``S```
1`````````````0``````````
